-- total revamp for ver 1.31
-- no longer any need to pre-process data files as they are no longer converted to .plugindata files
-- all this file does is define the LoadDefaults() function which is then called by main.lua (passing the IconInfo and MapInfo tables by reference so that they can be updated)

-- iconInfo is in the form {StringResourceID, Height, Width, Image ResourceID/Path, Highlighted Image ResourceID/Path, filterOrder,default icon, default hover icon, default clicked icon}

-- mapInfo pre-U29 is in the form {Index,StringResourceID, ImageResourceID/Path, Width, Height, HFactor,HOffset,WFactor,WOffset,ParentMapID,MapType,Region,MaxNS,MinEW,MinNS,MaxEW,Tier,StringResourceID_DE,StringResourceID_FR,StringResourceID_RU,{northern boundary points},{western boundary points},{southern boundary points},{eastern boundary points}}
-- mapInfo postU29 is in the form {Index,StringResourceID, ImageResourceID/Path, Width, Height, HFactor,HOffset,WFactor,WOffset,ParentMapID,MapType,Region,MaxNS,MinEW,MinNS,MaxEW,Tier,isInterior(0=false,nil=undefined/false,1=true),minZ(nil=0),maxZ(nil=infinity), {Region, N/S, E/W}}
-- HFactor and HOffset are used in the conversion from map coordinates to pixels: X=Height*HFactor+HOffset will convert coordinate "Height" to pixel "X"
-- -- the excel spreadsheet "MoorMap Data.xls" contains the calculated values using two points, one at top left of map, the other at bottom right of map.
-- -- source columns: B=top left NS, C=top left world EW, D=top left pixel world X, E=top left pixel Y, F=bottom right NS, G=bottom right world EW, H=bottom right pixel world X, I=bottom right pixel Y
-- -- calculated columns: J=hFactor, M=hOffset, N=wFactor, Q=wOffset
-- -- NOTE: this calculation does not need to be performed every time for internal maps. internal maps that are 800x600 will have a hFactor=300 and wFactor=-300 or hFactor=600 and wFactor=-600 - we can determine which by the size of the icons/cursor. Then all we need is the offset which should be determined from a single point, no longer needing four points. This would simplify internal maps considerably (and be more accurate)
-- -- -- when 300,300 offsets are 1/pixel when 600,600 offsets are 2/pixel
-- ParentMapID is used to create the tree structure
-- MapTypeID - 0=Undefined, 1=Parchment (coordinates match world coordinates), 2=Interior/Underground/Instanced (coordinates do NOT match world coordinates), 3=Interior/Underground subzone (hidden until parent is moused over in list and coordinates do not match world)
-- Region is the region code (from /loc) 0=Undefined/world map, 1=Eriador, 2=Rhovanion, 3=Gondor, 4=Mordor
-- Min&Max coordinates are the corners of the annotatable area of map - used to determine "best fit" when searching for a map by region/NS/EW
-- Tier is the zoom level of the map with "Middle Earth" being 1, "Eriador", "Rhovanion", "Rohan", "Gondor" and "Mordor" being 2, etc. this is used to determine the best map for adding annotations whose coordinates are included in more than one map
-- isInterior is a boolean flag which indicates that this map should only match coords that have a "cInside" token, this will help alleviate some of the co-ord issues caused by interiors in WoTP/Elderslades
-- minZ is a minimum value for the z coordinate, currently only used in interiors, nil=0
-- maxZ is a maximum value for the z coordinate, currently only used in interiors, nil=inifinite
-- parentCoords {region, NS, EW}, only used for interiors -- coordinates of the entrance to this interior, useful for determining world coords for interior locations
-- -- interesting issue, what to use for parent coords when it is an interior of an interior such as the Hall of Fire in The Last Homely House

-- the client shows interior maps as 800x600 in a 1024x768 frame offset at 112,84 and then stretched to whatever the current resolution is.
-- so, when processing a screenshot of an interior map, first resize the screenshot to 1024x768, then crop at 112,84 x 911,683, then resize to original dimension (interiors can be multiples of 800x600)

function LoadDefaults(tmpIconInfo,tmpMapInfo)
	local tmpIconInfo2={}
	tmpIconInfo2[1]={106,36,36,"MainBase.tga","MainBase_hover.tga","MainBase_icon.tga",1,"MainBase.tga","MainBase_hover.tga","MainBase_icon.tga"};
	tmpIconInfo2[2]={107,32,32,"Base.tga","Base_hover.tga","Base_icon.tga",2,"Base.tga","Base_hover.tga","Base_icon.tga"};
	tmpIconInfo2[3]={108,24,24,"Fort.tga","Fort_hover.tga","Fort_icon.tga",3,"Fort.tga","Fort_hover.tga","Fort_icon.tga"};
	tmpIconInfo2[4]={109,24,24,"Outpost.tga","Outpost_hover.tga","Outpost_icon.tga",4,"Outpost.tga","Outpost_hover.tga","Outpost_icon.tga"};
	tmpIconInfo2[5]={110,30,30,0x41005e5e,0x41005e60,0x41005e5f,7,0x41005e5e,0x41005e60,0x41005e5f}; -- poi
	tmpIconInfo2[6]={111,18,18,"Stockade.tga","Stockade_hover.tga","Stockade_icon.tga",5,"Stockade.tga","Stockade_hover.tga","Stockade_icon.tga"};
	tmpIconInfo2[7]={112,24,24,"Rez.tga","Rez_hover.tga","Rez_icon.tga",9,"Rez.tga","Rez_hover.tga","Rez_icon.tga"};
	tmpIconInfo2[8]={113,18,18,"CrudeMap.tga","CrudeMap_hover.tga","CrudeMap.tga",nil,"CrudeMap.tga","CrudeMap_hover.tga","CrudeMap.tga"};
	tmpIconInfo2[9]={114,18,18,"PoorMap.tga","PoorMap_hover.tga","PoorMap.tga",nil,"PoorMap.tga","PoorMap_hover.tga","PoorMap.tga"};
	tmpIconInfo2[10]={115,18,18,"GoodMap.tga","GoodMap_hover.tga","GoodMap.tga",6,"GoodMap.tga","GoodMap_hover.tga","GoodMap.tga"};
	tmpIconInfo2[11]={116,16,16,"NPC.tga","NPC_hover.tga","NPC.tga",10,"NPC.tga","NPC_hover.tga","NPC.tga"};
	tmpIconInfo2[12]={117,18,18,"FreepMap.tga","FreepMap_hover.tga","FreepMap.tga",nil,"FreepMap.tga","FreepMap_hover.tga","FreepMap.tga"};
	tmpIconInfo2[13]={118,18,18,"UnearnedMap.tga","UnearnedMap_hover.tga","UnearnedMap.tga",nil,"UnearnedMap.tga","UnearnedMap_hover.tga","UnearnedMap.tga"};
	tmpIconInfo2[14]={120,30,30,0x41005e9f,0x41005ea1,0x41005ea0,16,0x41005e9f,0x41005ea1,0x41005ea0}; -- auctioneer
	tmpIconInfo2[15]={121,32,32,"Barber.tga","Barber_hover.tga","Barber_icon.tga",17,"Barber.tga","Barber_hover.tga","Barber_icon.tga"};
	tmpIconInfo2[16]={122,30,30,0x41005e6a,0x41005e6c,0x41005e6b,18,0x41005e6a,0x41005e6c,0x41005e6b}; -- bard

	tmpIconInfo2[17]={123,30,30,0x410d4635,0x410d4637,0x410d4636,19,0x410d4635,0x410d4637,0x410d4636}; -- Camp Site (mini=0x410d4636 (15x15))
	tmpIconInfo2[18]={124,30,30,0x41005e76,0x41005e78,0x41005e77,20,0x41005e76,0x41005e78,0x41005e77}; -- Craft Facility

	tmpIconInfo2[19]={125,0,0,"placeholder.tga","placeholder.tga","placeholder.tga",nil,"placeholder.tga","placeholder.tga","placeholder.tga"}; -- ResourceNode NOT USED! This is separated into Ore, Wood, Scholar, etc
	tmpIconInfo2[20]={126,32,32,"CraftVendor.tga","CraftVendor_hover.tga","CraftVendor_icon.tga",21,"CraftVendor.tga","CraftVendor_hover.tga","CraftVendor_icon.tga"};
	tmpIconInfo2[21]={127,32,32,"FactionRep.tga","FactionRep_hover.tga","FactionRep_icon.tga",23,"FactionRep.tga","FactionRep_hover.tga","FactionRep_icon.tga"};
	tmpIconInfo2[22]={128,30,30,0x41005e88,0x41005e8a,0x41005e89,nil,0x41005e88,0x41005e8a,0x41005e89}; -- Fellow
	tmpIconInfo2[23]={129,0,0,"placeholder.tga","placeholder.tga","placeholder.tga",nil,"placeholder.tga","placeholder.tga","placeholder.tga"}; -- FellowLeader
	tmpIconInfo2[24]={130,30,30,0x41005e98,0x41005e9a,0x41005e99,nil,0x41005e98,0x41005e9a,0x41005e99}; -- FellowTrack
	tmpIconInfo2[25]={131,32,32,"Item-master.tga","Item-master_hover.tga","Item-master_icon.tga",24,"Item-master.tga","Item-master_hover.tga","Item-master_icon.tga"};
	tmpIconInfo2[26]={132,30,30,0x41005e94,0x41005e96,0x41005e95,25,0x41005e94,0x41005e96,0x41005e95};--Mailbox 
	tmpIconInfo2[27]={133,30,30,0x41005e52,0x41005e54,0x41005e53,26,0x41005e52,0x41005e54,0x41005e53}; -- milestone
	tmpIconInfo2[28]={134,0,0,"placeholder.tga","placeholder.tga","placeholder.tga",nil,"placeholder.tga","placeholder.tga","placeholder.tga"}; -- Pet
	tmpIconInfo2[29]={135,30,30,0x41005e4e,0x41005e50,0x41005e4f,nil,0x41005e4e,0x41005e50,0x41005e4f}; -- Quest NPC
	tmpIconInfo2[30]={136,0,0,"placeholder.tga","placeholder.tga","placeholder.tga",nil,"placeholder.tga","placeholder.tga","placeholder.tga"}; -- Quest Escort
	tmpIconInfo2[31]={137,30,30,0x41005e84,0x41005e86,0x41005e85,nil,0x41005e84,0x41005e86,0x41005e85}; -- Quest Failer
	tmpIconInfo2[32]={138,30,30,0x41005ea3,0x41005ea5,0x41005ea4,29,0x41005ea3,0x41005ea5,0x41005ea4}; -- reflecting pool
	tmpIconInfo2[33]={139,30,30,0x41005e56,0x41005e58,0x41005e57,30,0x41005e56,0x41005e58,0x41005e57}; -- Settlement
	tmpIconInfo2[34]={140,30,30,0x41005e72,0x41005e74,0x41005e73,31,0x41005e72,0x41005e74,0x41005e73}; -- stablemaster

	tmpIconInfo2[35]={141,32,32,"TownCrier.tga","TownCrier_hover.tga","TownCrier_icon.tga",37,"TownCrier.tga","TownCrier_hover.tga","TownCrier_icon.tga"};
	tmpIconInfo2[36]={142,30,30,0x41005e7f,0x41005e81,0x41005e80,nil,0x41005e7f,0x41005e81,0x41005e80}; -- Tracked Target
	tmpIconInfo2[37]={143,30,30,0x410d465c,0x410d465d,0x410d465a,38,0x410d465c,0x410d465d,0x410d465a}; -- Trader mini=0x410d465a (16x16)
	tmpIconInfo2[38]={144,30,30,0x41005e66,0x41005e68,0x41005e67,39,0x41005e66,0x41005e68,0x41005e67}; -- Trainer
	tmpIconInfo2[39]={145,30,30,0x41005e9d,0x41005e9d,0x41005e9e,41,0x41005e9d,0x41005e9d,0x41005e9e}; -- vaultkeeper doesn't have a highlighted icon with the other icons :(

	tmpIconInfo2[40]={146,30,30,0x41005e6e,0x41005e70,0x41005e6f,42,0x41005e6e,0x41005e70,0x41005e6f}; -- vendor
	tmpIconInfo2[41]={147,63,63,"MapConnector_blank.tga",0x410081a2,0x410081a2,nil,"MapConnector_blank.tga",0x410081a2,0x410081a2};
	tmpIconInfo2[42]={154,32,32,"SkirmishCamp.tga","SkirmishCamp_hover.tga","SkirmishCamp_icon.tga",43,"SkirmishCamp.tga","SkirmishCamp_hover.tga","SkirmishCamp_icon.tga"};
	tmpIconInfo2[43]={155,24,24,"OreNode.tga","OreNode_hover.tga","OreNode_icon.tga",11,"OreNode.tga","OreNode_hover.tga","OreNode_icon.tga"};
	tmpIconInfo2[44]={156,24,24,"WoodNode.tga","WoodNode_hover.tga","WoodNode_icon.tga",12,"WoodNode.tga","WoodNode_hover.tga","WoodNode_icon.tga"};
	tmpIconInfo2[45]={157,24,24,"ScholarNode.tga","ScholarNode_hover.tga","ScholarNode_icon.tga",13,"ScholarNode.tga","ScholarNode_hover.tga","ScholarNode_icon.tga"};
	tmpIconInfo2[46]={162,24,24,"Cook.tga","Cook_hover.tga","Cook_icon.tga",14,"Cook.tga","Cook_hover.tga","Cook_icon.tga"};
	tmpIconInfo2[47]={163,32,32,"MusterHorn.tga","MusterHorn_hover.tga","MusterHorn_icon.tga",27,"MusterHorn.tga","MusterHorn_hover.tga","MusterHorn_icon.tga"};
	tmpIconInfo2[48]={182,24,24,"Scholar.tga","Scholar_hover.tga","Scholar_icon.tga",15,"Scholar.tga","Scholar_hover.tga","Scholar_icon.tga"};
	tmpIconInfo2[49]={183,32,32,"Dungeon.tga","Dungeon_hover.tga","Dungeon_icon.tga",22,"Dungeon.tga","Dungeon_hover.tga","Dungeon_icon.tga"};
	tmpIconInfo2[50]={218,32,32,"Taskboard.tga","Taskboard_hover.tga","Taskboard_icon.tga",36,"Taskboard.tga","Taskboard_hover.tga","Taskboard_icon.tga"};
	tmpIconInfo2[51]={248,32,32,"StairUp.tga","StairUp_hover.tga","Stair_icon.tga",35,"StairUp.tga","StairUp_hover.tga","Stair_icon.tga"};
	tmpIconInfo2[52]={249,32,32,"StairDn.tga","StairDn_hover.tga","Stair_icon.tga",nil,"StairDn.tga","StairDn_hover.tga","Stair_icon.tga"};
	tmpIconInfo2[53]={272,30,30,0x41005e4e,0x41005e50,0x41005e4f,28,0x41005e4e,0x41005e50,0x41005e4f};
-- treasure chest icon from client, looks odd when stretched with full screen map :(
--	tmpIconInfo2[54]={318,32,32,0x410f33f4,"Treasure_hover.tga",0x411acef2,40,0x410f33f4,"Treasure_hover.tga",0x411acef2};
	tmpIconInfo2[54]={318,32,32,"Treasure.tga","Treasure_hover.tga",0x411acef2,40,"Treasure.tga","Treasure_hover.tga",0x411acef2};
	tmpIconInfo2[55]={323,30,30,"CPOI.tga","CPOI_hover.tga","CPOI_icon.tga",8,"CPOI.tga","CPOI_hover.tga","CPOI_icon.tga"}; -- custom POI
	tmpIconInfo2[56]={492,30,30,0x411da7e5,0x411da7e0,0x411da7df,32,0x411da7e5,0x411da7e0,0x411da7df}; -- far-ranging stablemaster
	tmpIconInfo2[57]={493,32,32,"Dockmaster.tga","Dockmaster_hover.tga","Dockmaster_icon.tga",34,"Dockmaster.tga","Dockmaster_hover.tga","Dockmaster_icon.tga"}; -- dockmaster
	tmpIconInfo2[58]={510,30,30,0x411da7e2,0x411da7e4,0x411da7e3,33,0x411da7e2,0x411da7e4,0x411da7e3}; -- eagle

-- treasure cache 16x16 0x411acef2

-- now update the current default values
	for k,v in ipairs(tmpIconInfo2) do
		if tmpIconInfo[k]==nil then
			table.insert(tmpIconInfo,Table.Copy(v))
		elseif tmpIconInfo[k][8]==nil then
			tmpIconInfo[k]=Table.Copy(v)
		else
			-- overwrite all the defaults
			tmpIconInfo[1]=tmpIconInfo2[1]
			tmpIconInfo[7]=tmpIconInfo2[7]
			tmpIconInfo[8]=tmpIconInfo2[8]
			tmpIconInfo[9]=tmpIconInfo2[9]
			tmpIconInfo[10]=tmpIconInfo2[10]
		end
	end
	-- Map Data
	tmpMapInfo[1]={1,19,0x41008133,1024,768,63.6,1541,-63.5,-630,3,1,1,-10,-24.3,-22,-8.2,3,0}; -- ettenmoors
	tmpMapInfo[2]={2,20,0x41008139,1024,768, 1, 0, 1, 0,0,1,0,0,0,0,0,1,0}; -- Middle Earth coordinates are meaningless on this map :( different systems are in use in Eriador and Rhovanion
	tmpMapInfo[3]={3,21,0x41008138,1024,768,6.5,951,-6.5,186,2,1,1,28.6,-146.4,-89.4,11.1,2,0}; -- Eriador ,0x4101E0AE,0x4101E0A8,0x410EE3C8
	tmpMapInfo[4]={4,22,0x41008131,1024,768,35.03,1498,-34.95,514,3,1,1,14.7,-42.8,-7.3,-13.6,3,0}; -- Angmar
	tmpMapInfo[5]={5,23,0x41008136,1024,768,33.0755711775,2223,-33.1240188383,-493,3,1,1,-17.7,-65.6,-38.9,-37.4,3,0}; -- Bree-land
	tmpMapInfo[6]={6,24,0x41008135,1024,768,182.68,9280,-182.62,-4414,5,1,1,-24.2,-50.8,-28.4,-45.2,4,0}; -- Archet ,0x4101E0A1,0x4101e0ba
	tmpMapInfo[7]={7,25,0x4110a841,1024,768,213.13,12203,-213.06,-6370,5,1,1,-29.9,-57.3,-33.5,-52.5,4,0}; -- Barrow Downs North
	tmpMapInfo[8]={8,26,0x4110a842,1024,768,173.38,10012,-174.32,-5700,5,1,1,-32.7,-57.8,-37.1,-51.9,4,0}; -- Barrow Downs South
	tmpMapInfo[9]={9,27,0x41008134,1024,768,150,8194,-150,-4210,5,1,1,-28.1,-54.6,-33.2,-47.8,4,0}; -- Bree
	tmpMapInfo[10]={10,28,0x410d9a54,1024,768,189.44,9468,-191.75,-6519,5,1,1,-34,-50,-38,-44.6,4,0}; -- Bree-land Homesteads
	tmpMapInfo[11]={11,29,0x410e4ddd,1024,768,79.90,5206,-79.90,-2332,5,1,1,-29.2,-65.2,-38.8,-52.4,4,0}; -- The Old Forest
	tmpMapInfo[12]={12,30,0x411041a4,1024,768,32.99,1041,-32.92,-1767,3,1,1,-53.7,-31.6,-77,-.6,3,0}; -- Enedwaith ,nil,nil,0x411041ac
	tmpMapInfo[13]={13,31,0x4100812c,1024,768,45.6696428571,5024,-45.6547619048,-566,3,1,1,-12.6,-113,-32.4,-86.6,3,0}; -- Ered Luin
	tmpMapInfo[14]={14,32,0x410d9934,1024,768,182.78,17099,-182.72,-4437,13,1,1,-24.93,-91.47,-27.76,-88.93,4,0}; -- Falathlorn Homesteads
	tmpMapInfo[15]={15,33,0x4100812b,1024,768,128.70,13735,-128.75,-1442,13,1,1,-11.2,-106.8,-17.2,-98.8,4,0}; -- Thorin's Gate
	tmpMapInfo[16]={16,34,0x410d9a56,1024,768,192.45,21143,-192.65,-2531,13,1,1,-13.2,-109.9,-17.2,-104.6,4,0}; -- Thorin's Hall Homesteads
	tmpMapInfo[17]={17,35,0x410e8686,1024,768,33.8,802,-33.75,-1188,3,1,1,-35.2,-23.8,-58,6.5,3,0}; -- Eregion ,nil,0x410f5e2f,0x411012D8
	tmpMapInfo[18]={18,36,0x410e8694,1024,768,138.8,1237,-139.5,-6765,17,1,1,-48.5,-9,-54,-1.6,4,0}; -- The Walls of Moria
	tmpMapInfo[19]={19,37,0x4101f084,1024,768,33.7,2783,-33.71,-53,3,1,1,-1.6,-82.6,-24.4,-52.3,3,0}; -- Evendim
	tmpMapInfo[20]={20,38,0x410E6EAD,1024,768,134.61,9890,-134.56,-2085,19,1,1,-15.5,-73.5,-21.2,-65.9,4,0}; -- Annuminas
	tmpMapInfo[21]={21,39,0x410e3f46,1024,768,25.02,2320,-25.07,625,3,1,1,24.9,-92.8,-5.7,-51.9,3,0}; -- Forochel
	tmpMapInfo[22]={22,40,0x4110d5a5,1024,768,213.13,20545,-213.06,3069,3,1,1,14.4,-96.4,10.8,-91.6,3,0}; -- Frostbluff
	tmpMapInfo[23]={23,41,0x41008130,1024,768,43.72,1935,-43.83,-1148,3,1,1,-26.2,-44.3,-43.7,-20.9,3,0}; -- Lone-lands
	tmpMapInfo[24]={24,42,0x4100812f,1024,768,41.30,489,-41.24,-602,3,1,1,-14.6,-11.9,-33.2,12.9,3,0}; -- Misty Mountains
	tmpMapInfo[25]={25,43,0x41008132,1024,768,36.28,2190,-36.18,-47,3,1,1,-1.3,-60.4,-22.5,-32.2,3,0}; -- North Downs
	tmpMapInfo[26]={26,44,0x41008137,1024,768,053.8421052632,4324,-53.6363636364,-1271,3,1,1,-22.9,-80.9,-38.8,-59.8,3,0}; -- The Shire
	tmpMapInfo[27]={27,45,0x410d9a57,1024,768,182.68,14130,-178.37,-6171,26,1,1,-34.6,-77.4,-38.9,-71.8,4,0}; -- Shire Homesteads
	tmpMapInfo[28]={28,46,0x4100812e,1024,768,37.61,988,-37.41,-778,3,1,1,-20.8,-26.3,-41.3,.9,3,0}; -- Trollshaws
	tmpMapInfo[29]={29,47,0x4100812d,1024,768,105.46,982,-106.53,-2801,28,1,1,-26.3,-9.4,-33.5,.3,4,0}; -- Rivendell
	tmpMapInfo[30]={30,48,0x411c2de4,1024,768,6.3067292645,802,-6.4516129032,288,2,1,2,42.4,-146.5,-86.9,24.6,2,0}; -- Rhovanion ,nil,nil,0x410f5e5a
	tmpMapInfo[31]={31,49,0x410e8707,1024,768,48.7,3995,-48.63,-223,30,1,2,-6.2,-80.92,-18.99,-62.13,3,0}; -- Lothlrien
	tmpMapInfo[32]={32,50,0x410e8706,1024,768,179.47,12568,-178.37,-2300,31,1,2,-12.9,-70,-17.2,-64.3,4,0}; -- Caras Galadhon
	tmpMapInfo[33]={33,51,0x41100DF2,1024,768,41.2,2618,-41.2,-200,30,1,2,-4.9,-63.6,-23.5,-38.8,3,0}; -- mirkwood
-- moria
	tmpMapInfo[34]={34,52,0x410e8708,1024,768,30,3653,-29.9,86,30,1,2,2.8,-121.8,-22.8,-87.7,3,0}; -- moria
	tmpMapInfo[35]={35,53,0x410e871d,1024,768,63.94,7289,-63.92,128,34,1,2,2,-114,-10,-98,4,0}; -- Durin's Way
	tmpMapInfo[36]={36,54,0x410e8716,1024,768,136.4,15286,-136.96,-1698,34,1,2,-12.4,-112.1,-18,-104.6,4,0}; -- Flaming Deeps
	tmpMapInfo[37]={37,55,0x410e8715,1024,768,132.86,13658,-132.24,-1401,34,1,2,-10.6,-102.8,-16.4,-95.1,4,0}; -- Foundations of Stone
	tmpMapInfo[38]={38,56,0x410e871a,1024,768,91.4,9612,-91.4,-365,34,1,2,-4,-105.2,-12.4,-94,4,0}; -- Nud Melek
	tmpMapInfo[39]={39,57,0x410e8718,1024,768,106.56,11632,-108.03,-1004,34,1,2,-9.3,-109.2,-16.4,-99.6,4,0}; -- Redhorn Lodes
	tmpMapInfo[40]={40,58,0x410e8e5a,1024,768,162.38,22967,-163.19,12060,34,3,2,73.9,-141.5,69.2,-135.2,4,0}; -- The Grand Stair
	tmpMapInfo[41]={41,59,0x410e871c,1024,768,141.8,16620,-141.8,-698,34,1,2,-4.9,-117.2,-10.3,-110,4,0}; -- The Great Delving
	tmpMapInfo[42]={42,60,0x410e8719,1024,768,142.08,16486,-142.04,-1221,34,1,2,-8.6,-116.1,-14,-108.9,4,0}; -- The Silvertine Lodes
	tmpMapInfo[43]={43,61,0x410e8717,1024,768,74.0566,8921,-73.9583,-835,34,1,2,-12.36,-117.56,-19,-109.07,4,0}; -- The Waterworks
	tmpMapInfo[44]={44,62,0x410e871b,1024,768,76.34,8700,-75.94,-296,34,1,2,-3.9,-114,-14,-100.6,4,0}; -- Zelem Melek
	tmpMapInfo[45]={45,63,0x410e871e,1024,768,134.61,15209,-134.56,2328,34,1,2,17.3,-113,11.6,-105.4,4,0}; -- Zirak Zigil
-- these are the first "interior" maps
	tmpMapInfo[46]={46,184,0x41005d2f,1600,1200,300,-13450,-300,23550,15,2,1,77.8,46.42,75.31,48.75,5,1,-214.04,nil}; -- Thorin's Hall main floor >=-214.04
	tmpMapInfo[47]={47,185,0x410d4163,1600,1200,300,-13450,-300,23550,15,2,1,77.1,47.08,76.54,48.06,5,1,nil,-214.05}; -- Thorin's Hall basement <=-214.05
	tmpMapInfo[48]={48,186,0x410d81c3,1600,1200,300,-15185,-300,-19395,1,2,1,-65.44,52.0,-67.85,54.53,4,1}; -- Delving of Fror

	tmpMapInfo[49]={49,187,0x41005c2f,800,600,1,0,1,0,5,3,1,0,0,0,0,4,1,nil,nil,{1,-21.3,-55.3}}; -- Breeland Brigand Cave
	tmpMapInfo[50]={50,188,0x41007dc5,800,600,600,-30310,-600,45403,15,3,1,75.4,50.97,74.97,51.41,5,1,nil,nil,{1,-15.7,-102.3}}; -- Rockbelly Pit
	tmpMapInfo[51]={51,189,0x41007dbe,1600,1200,803.7037037037,-41935,-806.0606060606,-4086,6,3,1,-5.46,52.54,-6.18,53.78,5,1,nil,nil,{1,-28,-48.2}}; -- Sprigley's Cellar
	tmpMapInfo[52]={52,190,0x41005C0D,800,600,597.5,-30229,-591.8918918919,45291,15,3,1,76.28,50.84,75.74,51.66,5,1,nil,nil,{1,-14.6,-104.9}}; -- Mirkstone Tunnels
	tmpMapInfo[53]={53,191,0x41005C1F,800,600,266.6666666667,-13009,-270.7317073171,21246,15,3,1,77.73,49.44,77.02,51.11,5,1,nil,nil,{1,-14.3,-101.6}}; -- Silver Deep
	tmpMapInfo[54]={54,192,0x41005C2D,1600,1200,400,-19806,-398.3739837398,32373,15,3,1,80.81,50.71,79,52.17,5,1,nil,nil,{1,-15.8,-102.5}}; -- Skorgrim's Tomb
	tmpMapInfo[55]={55,193,0x41110D27,800,600,1,0,1,0,19,3,1,0,0,0,0,4,1,nil,nil,{1,-16.4,-66.5}}; -- Annuminas: Haudh Valandur
	tmpMapInfo[56]={56,194,0x41110D29,800,600,1,0,1,0,19,3,1,0,0,0,0,4,1,nil,nil,{1,-16,-66.4}}; -- Annuminas: Haudh Erendur
	tmpMapInfo[57]={57,195,0x41110D2C,1600,1200,1,0,1,0,19,3,1,0,0,0,0,4,1,nil,nil,{1,-17.2,-66.8}}; -- Annuminas: Haudh Eldacar
	tmpMapInfo[58]={58,196,0x41110D2E,1600,1200,1,0,1,0,19,3,1,0,0,0,0,4,1,nil,nil,{1,-17.2,-66.3}}; -- Annuminas: Haudh Arantar
	tmpMapInfo[59]={59,197,0x4101fd4f,800,600,1,0,1,0,19,3,1,0,0,0,0,4,1,nil,nil,{1,-13.7,-76}}; -- Evendim: Gwindethrond
-- new RoI maps
	tmpMapInfo[60]={60,203,0x41119615,1024,768,31.2844,892,-31.3061,-2207,3,1,1,-70.5,-28.5,-95,4.2,3,0}; -- Dunlending ,nil,nil,0x41119612
	tmpMapInfo[61]={61,204,0x4111961d,1024,768,38.31461,1096,-38.1592,-2701,60,1,1,-70.8,-28.1,-90.9,-1.9,4,0}; -- Dunland ,nil,nil,0x41119622
	tmpMapInfo[62]={62,205,0x41116d55,1024,768,51.40704,1070,-51.4765,-4138,60,1,1,-80.4,-20.8,-94.4,-2.0,4,0}; -- Gap Of Rohan ,0x41116edc,0x41116edd,0x41116ee0
	tmpMapInfo[63]={63,206,0x41119607,1024,768,75.22059,715,-74.466,-5666,60,1,1,-76.1,-9.5,-86.0,3.8,4,0}; -- Nan Curunir ,nil,nil,0x4111960c
	tmpMapInfo[64]={64,207,0x41116EFE,1024,768,284.1667,5229,-284.074,-22413,61,1,1,-78.9,-18.4,-81.8,-14.8,5,0}; -- Galtrev ,nil,nil,0x41116f03
	tmpMapInfo[65]={65,208,0x41116f01,1024,768,132.8571,838,-132.241,-10090,63,1,1,-76.3,-6.3,-82.1,1.4,5,0}; -- Isengard ,nil,nil,0x41116f0c
-- Isengard Depths 0x4111923d
-- Ring of Isengard 0x41119257
	tmpMapInfo[66]={66,209,0x411195ff,1024,768,258.8745,24421.9,-256.585,13425.52,62,3,1,52.1,-93.7,49.6,-91.0,5,0}; -- Pit of Iron -- note, pit of iron is NOT an interior (like moria)

-- the great river maps
	tmpMapInfo[67]={67,214,0x4111e1c0,1024,768,37.61029,2780,-37.598,-646,30,1,2,-19.0,-73.9,-37.6,-46.7,3,0}; -- the great river ,0x4111e1c1,0x4111e1c2
	tmpMapInfo[68]={68,215,0x41123f09,1024,768,352.7586,22965,-348.636,-8681,67,1,2,-24.9,-65.1,-27.1,-62.2,4,0}; -- stangard
-- Tal Methedras
	tmpMapInfo[69]={69,216,0x4111b941,1024,768,113.289,1635.8,-112.794,-8132,60,1,1,-72.7,-12.3,-77.7,-7.1,4,0}; -- Tal Methedras after
	tmpMapInfo[70]={70,217,0x4111b941,1024,768,113.289,1635.8,-112.794,-8132,60,1,1,-72.7,-12.3,-77.7,-7.1,4,0}; -- Tal Methedras before

	tmpMapInfo[71]={71,228,0x41129eb7,1024,768,23.9019,1853.4,-23.8941,-799.452,301,1,2,-33.5,-77.5,-65.6,-34.7,3,0}; -- east rohan ,0x41129eb3,0x41129eb1
	tmpMapInfo[72]={72,229,0x4112d1dd,1024,768,76.9173,6108.2,-77.4747,-2664.13,71,1,2,-34.4,-79.4,-44.3,-66.1,4,0}; -- eaves of fangorn ,0x4112fcd6,0x4112fcd7
	tmpMapInfo[73]={73,230,0x4112d1dc,1024,768,42.9832,2635.9,-43.0899,-1968.21,71,1,2,-45.7,-61.3,-63.5,-37.5,4,0}; -- east wall ,0x4112fccd,0x4112fccf
	tmpMapInfo[74]={74,231,0x4112d1e1,1024,768,49.1827,3655.3,-48.8535,-1899.3,71,1,2,-38.9,-74.3,-54.6,-53.5,4,0}; -- entwash vale ,0x4112fcdb,0x4112fcdc
	tmpMapInfo[75]={75,232,0x4112d1e0,1024,768,47.1429,3159,-47.3457,-1982.78,71,1,2,-41.8,-67.0,-58.1,-45.3,4,0}; -- Norcrofts ,0x4112fcdf,0x4112fce1
	tmpMapInfo[76]={76,233,0x4112d1df,1024,768,51.6667,3612.5,-51.8243,-2714.59,71,1,2,-52.4,-69.9,-67.2,-50.1,4,0}; -- sutcrofts ,0x4112fce5,0x4112fce6
	tmpMapInfo[77]={77,234,0x4112d1de,1024,768,41.25,2649.3,-41.016,-1233.58,71,1,2,-30.1,-64.2,-48.8,-39.4,4,0}; -- The Wold ,0x4112fceb,0x4112fcec

-- RoR cities
	tmpMapInfo[78]={78,235,0x41132e10,1024,768,249.1525,13594,-250.185,-9457,77,1,2,-37.9,-54.6,-40.9,-50.5,5,0}; -- Harwick ,0x41132e11,0x41132e0f
	tmpMapInfo[79]={79,236,0x41132e57,1024,768,249.1409,15938,-249.791,-14803,76,1,2,-59.3,-64.0,-62.4,-59.9,5,0}; -- Snowbourn ,0x41132e59,0x41132e5b

	tmpMapInfo[80]={80,237,"GaranStuff/MoorMap/Maps/Cliving.jpg",1024,768,249.6104,14575,-250.181,-10517.6,75,1,2,-42.1,-58.4,-45.2,-54.3,5,0}; -- Cliving
	tmpMapInfo[81]={81,244,"GaranStuff/MoorMap/Maps/Eaworth.jpg",512,384,248.7179,16132,-250.877,-11765.35,74,1,2,-46.9,-64.9,-48.5,-62.9,5,0}; -- Eaworth
-- more interiors
	tmpMapInfo[82]={82,242,0x4112881f,1600,1200,601.8348623853,-31801,-593.75,13184,74,3,2,21.62,53.46,20.68,54.86,5,1,-23.0,nil,{2,-44.8,-66.5}}; -- Byrgenstow upper
	tmpMapInfo[83]={83,243,0x4112881e,1600,1200,598.1481481481,-31603,-597.6744186047,13269,74,3,2,21.62,53.46,20.68,54.86,5,1,nil,-23.1,{2,-44.8,-66.5}}; -- Byrgenstow lower

	tmpMapInfo[84]={84,245,0x4112a9de,800,600,401.0416666667,58308,-398.5263157895,-7498,76,3,2,-18.6,-145.7,-20.6,-143.2,5,1}; -- Langraf
	tmpMapInfo[85]={85,246,0x4112acb9,1600,1200,596.1038961039,-31660,-598.6394557823,35318,75,3,2,58.76,53.74,57.22,54.87,5,1}; -- Ost Magol lower
	tmpMapInfo[86]={86,247,0x4112acba,1600,1200,602.6666666667,-32019,-600.6802721088,35435,75,3,2,58.76,53.74,57.22,54.87,5,1}; -- Ost Magol upper
	tmpMapInfo[87]={87,250,0x4112d640,1600,1200,603.2,-30376,-596.7479674797,32265,74,3,2,53.9,50.7,52.3,52.3,5,1}; -- The Living Deep
	tmpMapInfo[88]={88,251,0x4112a39f,800,600,596.6176470588,-31521,-601.7948717949,36063,77,3,2,59.9,53,58.9,53.9,5,1}; -- Gerngarth 1
	tmpMapInfo[89]={89,252,0x4112a3a0,800,600,597.9411764706,-31592,-603.3333333333,36127,77,3,2,59.9,53,58.9,53.9,5,1}; -- Gerngarth 2
	tmpMapInfo[90]={90,253,0x41129d3d,1600,1200,601.6260162602,-30997,-598.4962406015,37234,76,3,2,62,51.9,60.3,53.6,5,1}; -- Isengraf
	tmpMapInfo[91]={91,254,0x4112884f,1600,1200,600,-32262,-600,14638,74,3,2,23.4,54.46,22.81,55.39,5,1}; -- Wyrmdelf 1
	tmpMapInfo[92]={92,255,0x4112884e,1600,1200,598.1308411215,-32160,-605.6338028169,14771,74,3,2,24.16,54.51,23.17,55.76,5,1}; -- Wyrmdelf 2
	tmpMapInfo[93]={93,256,0x4112a9af,800,600,297.9166666667,-15945,-298.9795918367,18625,75,3,2,61.82,54.34,60.79,55.38,5,1}; -- Dwergfant
	tmpMapInfo[94]={94,257,0x4112de9c,1600,1200,301.4814814815,-14078,-300,9211,75,3,2,29.84,48.46,27.6,50.08,5,1}; -- The Ancient Tomb
	tmpMapInfo[95]={95,258,0x4112a585,1600,1200,591.6666666667,-30503,-598.8636363636,35753,77,3,2,59.21,52.53,58.14,53.3,5,1}; -- Digelon Lower
	tmpMapInfo[96]={96,259,0x4112a584,1600,1200,602.2727272727,-31156,-600,35575,77,3,2,58.91,52.5,57.74,53.59,5,1}; -- Digelon Middle
	tmpMapInfo[97]={97,260,0x4112a586,800,600,606.3333333333,-31768,-607.6086956522,35692,77,3,2,58.55,52.78,57.92,53.33,5,1}; -- Digelon Upper
	tmpMapInfo[98]={98,261,0x4112ab42,1600,1200,300.4608294931,44259,-301.0101010101,-4643,76,3,2,-16.51,-146.04,-18.9,-143.49,5}; -- The Creeping Wood
-- goblin-town
	tmpMapInfo[99]={99,262,0x410d9810,1600,1200,298.8679245283,-15704,-301.5384615385,-20307,24,3,1,-67.58,53.46,-70.87,56.87,4,1}; -- Goblintown tunnels south
	tmpMapInfo[100]={100,263,0x410d9812,1600,1200,299.0147783251,-15742,-300,-19704,24,3,1,-66.5,54.11,-68.85,56.54,4,1}; -- Goblintown tunnels central
	tmpMapInfo[101]={101,264,0x410d9811,1600,1200,299.5744680851,-15953,-300.9561752988,-19333,24,3,1,-64.7,54.93,-67.65,57.03,4,1}; -- Goblintown tunnels north
	tmpMapInfo[102]={102,265,0x410d9813,800,600,304.4444444444,-16294,-297.3846153846,-19011,24,3,1,-64.56,54.47,-65.31,55.19,4,1}; -- Goblintown Slave Pens
	tmpMapInfo[103]={103,266,0x410d980d,800,600,302.8571428571,-16100,-298.8461538462,-18855,24,3,1,-63.47,53.87,-64.66,54.98,4,1}; -- Goblintown War Steadings
	tmpMapInfo[104]={104,267,0x410d980f,800,600,297.397260274,-15941,-299.298245614,-19603,24,3,1,-65.81,54.4,-67.16,55.46,4,1}; -- Goblintown Thundergrot
	tmpMapInfo[105]={105,268,0x410d9814,800,600,299.21875,-16180,-302.6153846154,-18931,24,3,1,-63.22,54.63,-63.97,56.17,4,1}; -- Gollums Cave
	tmpMapInfo[106]={106,269,0x410d980e,800,600,300.9090909091,-15951,-298.7878787879,-18514,24,3,1,-62.45,53.65,-63.57,54.83,4,1}; -- Goblintown Throne Room
	tmpMapInfo[107]={107,270,0x411295b6,800,600,604.4444444444,-31870,-596.2962962963,37748,76,3,2,62.97,52.98,62.63,53.58,5,1}; -- Parphad Upper
	tmpMapInfo[108]={108,271,0x411295b7,800,600,602.5210084034,-31767,-595.5,37697,76,3,2,63.12,52.76,62.47,54,5,1}; -- Parphad Lower

-- more Moria interiors
	tmpMapInfo[109]={109,274,0x410ea77c,800,600,601.5873015873,-33347,-592.5925925926,31842,35,3,2,53.37,55.7,53.08,56.46,5,1}; -- The Peaceful Path
	tmpMapInfo[110]={110,275,0x410ea77d,1600,1200,598.8235294118,-32695,-597.2727272727,33366,35,3,2,55.57,55.28,54.22,56.67,5,1}; -- Ghar-khafush
	tmpMapInfo[111]={111,276,0x410f4c06,800,600,297.6635514019,-16340,-301.9230769231,7998,35,3,2,26.05,55.64,24.92,56.83,5,1}; -- Buzun-ghar
-- RoR Wildermore
	tmpMapInfo[112]={112,277,0x411375af,1024,768,38.7719,3009.2,-38.6233,-1044.19,71,1,2,-27.1,-77.7,-45.4,-53.9,4,0}; -- Wildermore ,0x411375a9,0x411375ad
	tmpMapInfo[113]={113,278,0x411379ff,1024,768,334.7517,20914,-334.9282297,-12542,112,1,2,-37.5,-62.5,-39.8,-59.5,5,0}; -- Forlaw ,0x41137a01,0x411379fd
-- RoR Westemnet
	tmpMapInfo[114]={114,287,0x4113C325,1024,768,19.40299,1892,-19.3191,-760,301,1,2,-39.3,-97.6,-79.0,-44.8,3,0}; -- west rohan,0x41142C46,0x41142C4b
	tmpMapInfo[115]={115,288,0x4113C31F,1024,768,30.91317,2678,-30.9563,-1575,114,1,2,-50.9,-86.6,-75.6,-53.6,4,0}; --kingstead ,0x41142C3D,0x41142C4F
	tmpMapInfo[116]={116,289,0x4113C320,1024,768,64.03197,4997,-63.6986,-2646,114,1,2,-41.6,-78.1,-53.5,-62.1,4,0}; -- broadacres ,0x41142C4E,0x41142C3F
	tmpMapInfo[117]={117,290,0x4113C321,1024,768,45.08133,3202,-45.3157,-2719,114,1,2,-60.0,-71.0,-77.0,-48.4,4,0}; -- eastfold ,0x41142C42,0x41142C3C
	tmpMapInfo[118]={118,291,0x4113C322,1024,768,50.08547,4464,-49.842,-2196,114,1,2,-44.1,-89.2,-59.4,-68.7,4,0}; -- stonedeans ,0x41142C51,0x41142C3E
	tmpMapInfo[119]={119,292,0x4113C323,1024,768,119.3396,11134,-118.373,-7141,114,1,2,-60.3,-93.3,-66.8,-84.7,4,0}; -- helm's deep ,0x41142C38,0x41142C4D
	tmpMapInfo[120]={120,293,0x4113C324,1024,768,45.26823,4306,-45.1091,-2366,114,1,2,-52.5,-95.2,-69.4,-72.5,4,0}; -- westfold ,0x41142C52,0x41142C55
	tmpMapInfo[121]={121,294,0x4113C31E,1024,768,129.0462,9921,-129.122,-7510,115,1,2,-58.2,-76.9,-64.1,-69.0,5,0}; -- edoras ,0x41142C3A,0x41142C54
	tmpMapInfo[122]={122,296,0x4114BEAA,1024,768,103.2885,8944,-103.14,-3846,114,1,2,-37.29,-86.6,-44.73,-76.69,4,0}; -- entwood
	tmpMapInfo[123]={123,297,0x4114E11C,1024,768,73.71865,7142,-73.7095,-3134,114,1,2,-42.6,-96.9,-53,-83.1,4,0}; -- isengard (flooded)
-- West Gondor
	tmpMapInfo[124]={124,304,0x41154336,1024,768,9.4941956882,936,-9.9729241877,-234,2,1,3,-52.7,-86.6,-81.3,-49,2,0}; -- Gondor
	tmpMapInfo[125]={125,298,0x411538df,1024,768,23.788443616,2144,-23.7451050196,-1200,124,1,3,-50.6,-90.2,-82.9,-47.2,3,0}; -- west gondor
	tmpMapInfo[126]={126,299,0x41154eed,1024,768,37.6321353066,3128,-37.5598086124,-1916,125,1,3,-51.1,-83.2,-71.1,-56.2,4,0}; -- blackroot vale
	tmpMapInfo[127]={127,300,0x41154eeb,1024,768,37.4069478908,3155,-37.5686813187,-2515,125,1,3,-67,-84.3,-87.4,-57.3,4,0}; -- havens of belfalas
	tmpMapInfo[128]={128,301,0x41154e05,1024,768,158.6330935252,11805,-158.6283185841,-11483,127,1,3,-72.4,-74.5,-77.2,-68,5,0}; -- dol amroth
	tmpMapInfo[129]={129,302,0x41154eec,1024,768,46.9821757837,3335,-47.0261437908,-2742,125,1,3,-58.4,-71,-74.6,-49.3,4,0}; -- lamedon
	tmpMapInfo[130]={130,303,0x41154c34,1024,768,160,12526,-160.2409638554,-6735,125,1,3,-42.1,-78.3,-46.9,-71.9,4,0}; -- PotD

	tmpMapInfo[131]={131,305,0x41158979,1024,768,110.2013422819,2147,-109.8666666667,-2750,124,1,3,-25.0,-19.5,-32.0,-10.2,3,0}; --dead marshes

	tmpMapInfo[132]={132,306,0x4115b943,1024,768,31.2684365782,1864,-31.4232902033,-2095,124,1,3,-66.6,-59.7,-91.1,-26.9,3,0}; -- Cental gondor
	tmpMapInfo[133]={133,307,0x4115b93f,1024,768,81.1240721103,4626,-81.4814814815,-5582,132,1,3,-68.5,-57.0,-77.9,-44.4,4,0}; -- Ringlo
	tmpMapInfo[134]={134,308,0x4115b944,1024,768,56.8965517241,2741,-56.8325791855,-4256,132,1,3,-74.9,-48.2,-88.4,-30.2,4,0}; -- Lebennin
	tmpMapInfo[135]={135,309,0x4115b93c,1024,768,147.6525821596,5538,-147.9797979798,-12107,134,1,3,-81.8,-37.5,-87.0,-30.6,5,0}; -- Pelargir
	tmpMapInfo[136]={136,310,0x4115b945,1024,768,60.0821167883,3553,-60.1128880527,-4525,132,1,3,-75.3,-59.2,-88.0,-42.1,4,0}; -- Dor-en-ernil
	tmpMapInfo[137]={137,311,0x4115b98b,1024,768,192.3346303502,10896,-192.1204188482,2995,199,1,2,15,-54.9,12.4,-52.1,4,0}; -- Grimbeorn's House
-- eastern gondor
	tmpMapInfo[138]={138,312,0x4115ee35,1024,768,27.4534553487,999,-27.533632287,-1628,124,1,3,-59.2,-36.4,-87.0,0.4,3,0}; -- Eastern Gondor
	tmpMapInfo[139]={139,313,0x4115ee38,1024,768,67.6829268293,2526,-67.5175175175,-4987,138,1,3,-73.9,-37.4,-85.2,-22.2,4,0}; -- Upper Lebennin
	tmpMapInfo[140]={140,314,0x4115ee3a,1024,768,38.6494252874,1024,-38.8235294118,-2341,138,1,3,-60.3,-26.5,-80.1,-0.1,4,0}; -- South Ithilien
	tmpMapInfo[141]={141,315,0x4115ee3c,1024,768,59.9740090968,1968,-60.0481347774,-4176,138,1,3,-69.6,-32.8,-82.4,-15.8,4,0}; -- Lossarnach
	tmpMapInfo[142]={142,316,0x4115ee41,1024,768,106.0877192982,1431,-106.4220183486,-6252,140,1,3,-58.7,-13.5,-66.0,-3.9,5,0}; -- Osgiliath
	tmpMapInfo[143]={143,317,0x41162479,1024,768,106.0877192982,1431,-106.4220183486,-6252,140,1,3,-58.7,-13.5,-66.0,-3.9,5,0}; -- Osgiliath (PvMP)
	tmpMapInfo[144]={144,319,0x411656ee,1024,768,43.7535014006,1150,-43.75,-1964,147,1,3,-44.9,-23.5,-62.2,-6.5,4,0}; -- Talath Anor
	tmpMapInfo[145]={145,320,0x411656ef,1024,768,112.6033057851,2712,-112.8846153846,-7017,146,1,3,-62.5,-21.2,-68.74,-15.6,5,0}; -- Minas Tirith
	tmpMapInfo[146]={146,321,0x411656f0,1024,768,51.3146734521,1426,-51.4705882353,-3002,147,1,3,-62.9,-21.0,-68.0,-16.2,4,0}; -- Pelennor
	tmpMapInfo[147]={147,322,0x411656f1,1024,768,26.2916188289,891,-26.2782401902,-1172,124,1,3,-44.6,-24.3,-72.6,-7.0,3,0}; -- Old Anorien

	tmpMapInfo[148]={148,334,0x4116af91,1024,768,29.9934832193,1511,-29.9574468085,-972,124,1,3,-32.4,-50.3,-53.8,-16.3,3,0}; -- Far Anorien
	tmpMapInfo[149]={149,335,0x4116af8b,1024,768,41.2196356275,2112,-41.1783644559,-1310,148,1,3,-31.8,-51.2,-49.5,-26.4,4,0}; -- Beacon Hills
	tmpMapInfo[150]={150,336,0x4116af90,1024,768,48.7486965589,1651,-48.7216946676,-2071,148,1,3,-42.5,-33.8,-58.2,-12.9,4,0}; -- Taur Druadan

	tmpMapInfo[151]={151,341,0x411aef51,1024,768, 37.9381443299,2991,-37.9754601227,-2904,125,1,3, -80.6,-78.7,-95.5,-52.1,4,0}; -- Cape of Belfalas new
	tmpMapInfo[152]={152,338,0x411a4333,1024,768, 11.6480446927,231,-11.3679245283,-327,2,1,4, -13.4,-19.9,-110,127.2,2,0}; -- Mordor
	tmpMapInfo[153]={153,339,0x411a42e8,1024,768, 41.5248691099,1172,-41.6829745597,-2273,154,1,4, -55.1,-24.1,-72.5,-4.3,5,0}; -- Pelennor after battle
	tmpMapInfo[154]={154,340,0x411a42e7,1024,768, 27.7462792346,793,-27.5147928994,-1086,155,1,4, -39.7,-25.5,-67.1,3.2,4,0}; -- North Ithilien
	tmpMapInfo[155]={155,337,0x411a4436,1024,768, 23.7138263666,824,-23.8176314794,-945,152,1,4, -39.7,-26.7,-71.7,3.2,3,0}; -- March of the king
	tmpMapInfo[156]={156,342,0x411a42e5,1024,768, 136.3287250384,1798,-136.5778688525,-8132,153,1,4, -60,-12.3,-65,-6,6,0}; -- Osgiliath after battle
	tmpMapInfo[157]={157,344,0x4119389d,1024,768, 112.6033057851,2712,-112.8846153846,-7017,153,1,4,-62.5,-21.2,-68.74,-15.6,6,0}; -- Minas Tirith after battle
	tmpMapInfo[158]={158,343,0x41193988,1024,768, 0,0,0,0,155,3,4, -0,-0,0,0,4,0}; -- Throne of the dread terror ? instance?
	tmpMapInfo[159]={159,346,0x411ad8a9,1024,768, 49.9066583696,850,-49.9230769231,-1304,152,1,4, -26.2,-17.1,-41.5,3.4,3,0}; -- Wastes
	tmpMapInfo[160]={160,347,0x411ad936,1024,768, 0,0,0,0,159,3,4, -0,-0,0,0,4,0}; -- Battle of the Black Gate ? instance?
	tmpMapInfo[161]={161,360,0x411b84d4,1024,768, 22.5319006044,133,-22.5579470199,-798,152,1,4, -37.1,-3.9,-67.6,36,3}; -- Plateau of Gorgoroth
	tmpMapInfo[162]={162,361,0x411bca58,1024,768, 0,0,0,0,161,3,4, -0,-0,0,0,4,0}; -- Morannon war of the last alliance instance
	tmpMapInfo[163]={163,362,0x411b9591,1024,768, 62.4282198523,269,-62.5754527163,-2299,161,1,4, -37.2,-3.7,-48.6,10,4,0}; -- Udun
	tmpMapInfo[164]={164,363,0x411b958e,1024,768, 35.0233426704,226,-35.039817975,-1578,161,1,4, -45.4,-.7,-65.8,19.5,4,0}; -- Lhingris
	tmpMapInfo[165]={165,364,0x411b9590,1024,768, 42.5565491846,-287,-42.5475599669,-2039,161,1,4, -52,9,-65.2,29.9,4,0}; -- Talath Urui
	tmpMapInfo[166]={166,365,0x411b958c,1024,768, 47.5978647687,-870,-47.5425330813,-1992,161,1,4, -45.1,23.7,-57.5,38,4,0}; -- Agarnaith
	tmpMapInfo[167]={167,366,0x411b958d,1024,768, 43.8020578148,-262,-43.797856049,-1626,161,1,4, -42.1,6.5,-52.8,27.3,4,0}; -- Dor Amarth
	tmpMapInfo[168]={168,367,0x411b958f,1024,768, 62.490508732,-692,-62.5809935205,-2850,161,1,4, -46.5,11.9,-57.1,26.5,4,0}; -- Orodruin
	tmpMapInfo[169]={169,368,0x411bbfd1,1024,768, 169.7211155378,-1892,-168.8811188811,3290,165,1,4, 18.7,11.6,15.3,16.5,5,0}; -- Nargroth
	tmpMapInfo[170]={170,369,0x411bbfd0,1024,768, 0,0,0,0,168,1,4, -0,-0,0,0,5,0}; -- Sammath
	tmpMapInfo[171]={171,370,0x411c2de2,1024,768,23.8258317025,1348,-23.8938053097,892,30,1,2,35,-52.1,8.4,-18,3,0}; -- Eryn Lasgalen (North Mirkwood)
	tmpMapInfo[172]={172,371,0x411c2de1,1024,768,191.8644067797,24755,-191.3725490196,9571,171,1,2,50,-129,46,-123.7,4,0}; -- Felegoth
	tmpMapInfo[173]={173,372,0x411bc61b,3200,2400,609.5238095238,-30997,-601.7857142857,9109,181,3,4,15.1,50.8,11.1,56,5,1}; -- Hall Under the Mountain
	tmpMapInfo[174]={174,373,0x411c3a74,1024,768,142.0833333333,2898,-142.037037037,-1648,33,1,2,-11.6,-20.4,-17,-13.2,4,0}; -- Dol Guldur (Razed)
	tmpMapInfo[175]={175,374,"GaranStuff/MoorMap/Maps/Dale.jpg",1024,768,373.8805970149,10051,-376.3440860215,9578,171,1,2,25.34,-26.85,23.48,-24.17,4,0}; -- Dale
	tmpMapInfo[176]={176,375,"GaranStuff/MoorMap/Maps/Laketown.jpg",1024,768,498.8023952096,13985,-498.1651376147,8978,171,1,2,17.95,-27.91,16.86,-26.24,4,0}; -- Laketown
	tmpMapInfo[177]={177,376,0x411c8da9,1024,768,40,2285,-40.0894187779,1858,30,1,2,45.6,-56.7,28.3,-32.5,3,0}; -- ered mithrin
	tmpMapInfo[178]={178,377,0x411cd4b8,1024,768,46.2332301342,1090,-46.3096960926,1545,30,1,2,32.5,-23.1,17.4,-2.1,3,0}; -- iron hills
	tmpMapInfo[179]={179,378,0x411ce4fc,1024,768,192.0634920635,26633,-193.2735426009,5020,177,2,2,25.33,-137.57,22.45,-134.31,4,0}; -- thikil-gundu note, NOT interior
	tmpMapInfo[180]={180,379,0x411ce735,1024,768,192.2330097087,26726,-194,6435,177,2,2,32.9,-138,29.5,-135.88,4,0}; -- glimmerdeep NOT interior
	tmpMapInfo[181]={181,380,0x411ce74f,1024,768,191.2280701754,26388,-191.4027149321,3140,171,1,2,15.7,-137.6,12.8,-133.4,4,0}; -- erebor
	tmpMapInfo[182]={182,381,0x411c5f05,2400,1800,801.0101010101,-41447,-794,39228,178,3,2,48.98,52.54,47.94,54.21,4,1}; -- jarnfast
	tmpMapInfo[183]={183,382,0x411d2eba,1024,768,0,0,0,0,177,1,2,0,0,0,0,4,0}; -- the anvil of winterstith raid instance
	tmpMapInfo[184]={184,383,0x411c7d9d,1600,1200,289.6551724138,-14148,-312,18197,177,2,2,56.94,51.39,56.2,51.99,4,1}; -- stormwall (entrance to Thrumfall)
	tmpMapInfo[185]={185,384,0x411c8712,2400,1800,790.6976744186,-39127,-802.7777777778,44957,184,3,2,55.8,50.07,53.91,51.94,5,1}; -- Caverns of Thrumfall
	tmpMapInfo[186]={186,385,0x41125525,800,600,670.5882352941,-34446,-602.2727272727,11901,43,3,2,19.76,51.36,18.76,52.55,5,1}; -- Moria Hulwul-nefekh
	tmpMapInfo[187]={187,386,0x410f5deb,800,600,816.6666666667,-45615,-804,50971,35,3,2,63.39,55.85,62.65,56.82,5,1}; -- Moria Chamber of Command
	tmpMapInfo[188]={188,387,0x4112b2e6,1600,1200,600,-32068,-598.9010989011,33460,74,3,2,55.42,54.42,54.3,55.07,5,1,nil,-102.48}; -- Haycliff 1 (overlaps haycliff2 on path up above -102.48)
	tmpMapInfo[189]={189,388,0x4112b2e8,1600,1200,594.5945945946,-31774,-600,33404,74,3,2,55.23,54.49,54.09,54.96,5,1,-102.49,-62.15}; -- Haycliff 2  -106.24! (-102.49 rope) to -61.24 overlaps haycliff 1 and 3 :( arghhhhh
	tmpMapInfo[190]={190,389,0x4112b2e7,800,600,591.3043478261,-31992,-598.5074626866,33023,74,3,2,55.04,54.49,54.3,54.96,5,1,-62.14,nil}; -- Haycliff 3  -62.14 (at rope)
	tmpMapInfo[191]={191,391,0x410ea791,1600,1200,601.2048192771,-33011,-597.2602739726,18304,38,3,2,30.4,55.38,28.87,57.09,5,1}; -- Moria Mamalsul
	tmpMapInfo[192]={192,392,0x410ea77f,1600,1200,299.2084432718,-15543,-299.3377483444,18027,43,3,2,59.12,52.61,57.31,56.62,5,1}; -- Moria Drowned Treasury
	tmpMapInfo[193]={193,393,0x410ea782,1600,1200,605.8823529412,-33175,-595.0617283951,36759,43,3,2,61.27,55.52,60.25,56.61,5,1}; -- Moria Deep-way
	tmpMapInfo[194]={194,394,0x410ea781,1600,1200,598.3606557377,-32903,-597.9797979798,36266,43,3,2,60.25,55.64,59.03,57.01,5,1}; -- Moria Way of Smiths
	tmpMapInfo[195]={195,395,0x410ea77b,800,600,600,-33235,-603.3333333333,31408,37,3,2,51.85,55.81,51.25,56.31,5,1}; -- Moria Gwathrendath
--*** Azanarukar instance needs testing
	tmpMapInfo[196]={196,396,0x410ea775,800,600,298.4615384615,-16544,-297.2222222222,13684,37,3,2,45.43,56.36,44.62,57.17,5,1,-54.49,nil}; -- Moria Azanarukar upper i24 max oz ? min oz -54.49
	tmpMapInfo[197]={197,397,0x410ea776,1600,1200,610.8108108108,-33876,-603.5087719298,27654,37,3,2,45.31,56.47,44.31,57.06,5,1,-84.49,-54.50}; -- Moria Azanarukar mid i24 max oz -54.50 min oz -84.49
	tmpMapInfo[198]={198,398,0x410ea777,1600,1200,590.9090909091,-32689,-598.5294117647,27582,37,3,2,45.83,56.36,44.32,56.98,5,1,-84.50,nil}; -- Moria Azanarukar lower i24 max oz -84.5 min oz 
	tmpMapInfo[199]={199,399,0x411da4a0,1024,768,24.9741735537,2030,-25.0338294993,458,30,1,2,17.05,-71.97,-10.9,-46.45,3,0}; -- Vales of Anduin
	tmpMapInfo[200]={200,400,0x411d9e32,800,600,597.2222222222,-31406,-614.8148148148,33860,199,3,2,54.86,53.02,54.32,53.52,4,1}; -- Avabarg
	tmpMapInfo[201]={201,402,0x411da1dd,800,600,597.0588235294,-30401,-597.8723404255,23656,199,3,2,39.3,51.34,38.78,51.76,4,1}; -- Tun Melen
	tmpMapInfo[202]={202,403,0x411e9a41,1024,768,35.5478704041,444,-35.6223942823,-2010,161,1,4,-57.3,-6.8,-76.9,12.7,4,0}; -- Morgul Vale
	tmpMapInfo[203]={203,404,0x411e9a42,1024,768,140.8983799705,192,-141.0138248848,-9103,202,1,4,-65.1,-0.8,-69.3,3.9,5,0}; -- Minas Morgul
	tmpMapInfo[204]={204,405,0x411e9a43,1024,768,45.009299442,6029,-45.2768729642,-4017,167,2,4,-89.8,-133.3,-104.1,-111.9,5,0}; -- Mordor Besieged - not sure why this is a child of Dor Amarth but that's where the game takes you if you right click on the built-in version...
	tmpMapInfo[205]={205,406,0x411ea2fa,1024,768,119.8417721519,-1081,-120.1927710843,4323,202,2,4,35.7,10.61,30.2,15.62,5,0}; -- Torech Ungol
	tmpMapInfo[206]={206,407,0x411daba0,800,600,298,-12525,-300.7575757576,-18035,199,3,2,-60.17,42.64,-61.76,43.95,4,1}; -- Shathur-munzu
	tmpMapInfo[207]={207,408,0x411daa48,1600,1200,597.9797979798,-31294,-597.7443609023,22718,199,3,2,37.83,53.09,36.26,54.55,4,1}; -- Kidzul-kalah
	tmpMapInfo[208]={208,409,0x411e993f,800,600,588.8888888889,67956,-604.7826086956,-71976,204,3,4,-119.16,-114.89,-119.87,-114.57,6,1}; -- Amon Fuin
-- break Anglach into two levels?
	tmpMapInfo[209]={209,421,0x411babda,1600,1200,500.6578947368,-26661,-499.1304347826,36917,163,3,4,73.56,54.04,71.96,55.64,5,1}; -- The Great Foundry (Mordor) upper floor
	tmpMapInfo[210]={210,422,0x411af37e,1600,1200,600.9708737864,-32166,-600.8064516129,46892,163,3,4,77.75,54.15,76.4,55.55,5,1}; -- Durthang
	tmpMapInfo[211]={211,423,0x411baf90,1600,1200,400.6968641115,-20118,-400,-282,167,3,4,-1.74,50.25,-2.66,54.1,5,1}; -- Dungeons of Barad-dur
	tmpMapInfo[212]={212,424,"GaranStuff/MoorMap/Maps/KamLagurz.jpg",1600,1600,249.6753246753,-7289,-250.4739336493,4908,164,2,4,19.59,29.19,13.23,35.58,5,0}; -- Kam Lagurz
	tmpMapInfo[213]={213,425,"GaranStuff/MoorMap/Maps/GlitteringCaves.jpg",1600,1400,250.2793296089,36339,-250.6666666667,-14942,119,3,2,-59.65,-145.18,-65.17,-138.83,5,0}; -- Glittering Caves
	tmpMapInfo[214]={214,426,0x41091b65,1600,1200,600.3355704698,-31381,-599.8076923077,39676,13,3,1,65.95,52.85,64.33,54.38,4,1}; -- Sarnur Great Hall
	tmpMapInfo[215]={215,427,0x41091b64,800,600,260.6796116505,-12773,-259.7701149425,17352,13,3,1,66.6,50,64.7,51.06,4,1}; -- Sarnur Keep
	tmpMapInfo[216]={216,428,0x41091b63,1600,1200,599.2063492064,-29975,-600.5,39815,13,3,1,65.83,50.67,64.77,52,4,1}; -- Sarnur Caverns
	tmpMapInfo[217]={217,429,0x411ba624,2400,1800,902.8571428571,-46946,-898.7179487179,8806,165,3,4,9.77,52.72,7.81,53.92,5,1}; -- Naerband
	tmpMapInfo[218]={218,430,0x411baf8c,800,600,300,-16029,-300,575,167,3,4,1.37,54.28,0.45,55.23,5,1}; -- Lughash
	tmpMapInfo[219]={219,431,"GaranStuff/MoorMap/Maps/Mordath.jpg",1600,1800,250,31698,-250,-2300,167,3,4,-9.2,-126.8,-16.36,-120.41,5,0}; -- Mordath
	tmpMapInfo[220]={220,432,0x411bd2b2,2400,1800,900,-48230,-902.6548672566,37008,165,3,4,40.98,54.31,39.16,55.52,5,1}; -- dungeons of naerband
	tmpMapInfo[221]={221,433,"GaranStuff/MoorMap/Maps/Ja-kuru.jpg",1200,800,250.9578544061,18767,-250.3496503497,15119,21,3,1,60.37,-74.77,57.2,-70.02,4,0}; -- Ja-kuru

	tmpMapInfo[222]={222,434,0x411DBADC,1600,1200,598.3050847458,-31968,-600.2702702703,37535,202,3,4,62.53,54.4,60.54,55.11,5,1}; -- Bar Daenath
	tmpMapInfo[223]={223,435,0x411e6f2d,800,600,601.4705882353,-33524,-600,32218,203,3,4,53.65,56.04,52.73,56.75,6,1}; -- Barad Orhant
	tmpMapInfo[224]={224,436,0x411e6f26,800,600,602.9411764706,-33607,-596.875,33964,203,3,4,56.85,56.04,55.94,56.75,6,1}; -- Barad Angarth
	tmpMapInfo[225]={225,437,0x411e78af,1600,1200,597.0588235294,-31921,-600,34081,203,3,4,56.49,54.44,55.15,55.14,6,1}; -- Burzangh
	tmpMapInfo[226]={226,438,0x411e6e6e,800,600,601.4705882353,-33525,-600,35097,203,3,4,58.39,56.04,57.54,56.75,6,1}; -- Barad Elnath
	tmpMapInfo[227]={227,439,0x411e6f2e,800,600,602.1739130435,-33565,-597.7777777778,33057,203,3,4,55.25,56.04,54.34,56.75,6,1}; -- Barad Arthir
	tmpMapInfo[228]={228,440,0x411e6641,800,600,594.5945945946,-33143,-603.4482758621,7352,203,3,4,11.85,56.16,11.25,56.66,6,1,nil,-46.12,{203,-67.8,1.7}} -- hall of the moon
	tmpMapInfo[229]={229,441,0x411e6642,800,600,602.1739130435,-33569,-598.9583333333,7300,203,3,4,11.81,56.18,11.26,56.63,6,1,-46.11,nil,{203,-67.8,1.7}}; -- Beacon-chamber
	tmpMapInfo[230]={230,442,0x411e9f8f,800,600,611.1111111111,-33945,-596.5517241379,28220,203,3,4,46.99,55.95,46.6,56.44,6,1}; -- The Wracking-hall
	tmpMapInfo[231]={231,443,0x411e7884,800,600,596,-32263,-598.5915492958,34899,203,3,4,58.27,54.32,57.3,55.27,6,1}; -- Dar Grazadh
	tmpMapInfo[232]={232,444,0x411e9c65,2400,1800,1200.5050505051,-65969,-1198.4848484848,80360,203,3,4,66.65,55.44,65.94,56.45,6,1}; -- Ghashan Kutot
	tmpMapInfo[233]={233,445,0x411e9fe1,800,600,603.5714285714,-33581,-607.8947368421,26773,203,3,4,43.74,56.14,43.34,56.44,6,1}; -- Bar Maenath
	tmpMapInfo[234]={234,446,0x411e78d3,800,600,603.5714285714,-32676,-603.5714285714,33376,203,3,4,54.95,54.64,54.64,54.94,6,1}; -- Roz Dagalur
	tmpMapInfo[235]={235,447,0x411ba92e,1600,2400,798.9130434783,-42985,-804.8076923077,60752,205,3,4,74.58,54.04,73.49,55.05,6,1}; -- Tower of Cirith Ungol - note, the aspect ratio of this map is severely skewed... 8p
	tmpMapInfo[236]={236,448,0x411ecbe3,1024,768,61.2574850299,9059,-61.36,1773,202,3,4,28.9,-147.9,16.4,-131.2,5,0}; -- shelob's lair
	tmpMapInfo[237]={237,449,0x411e9f97,800,600,600,-33485,-600,27462,203,3,4,45.44,56.33,45.12,56.64,6,1}; -- The Gloomwaters
	tmpMapInfo[238]={238,450,0x411dac83,3200,2400,597.1223021583,-30877,-600,41947,203,3,4,69.9,51.71,65.91,57.04,6,1}; -- Gath Daeroval
	tmpMapInfo[239]={239,451,0x411e9f6f,800,600,601.4705882353,-33343,-603.3333333333,6335,203,3,4,10.18,55.74,9.79,56.44,6,1}; -- Uialrond
	tmpMapInfo[240]={240,452,"GaranStuff/MoorMap/Maps/BarNirnaeth.jpg",1200,1200,251.6666666667,10765,-250.3184713376,17120,202,3,4,68.39,-42.78,63.62,-38.01,5,0}; -- Bar Nirnaeth
	tmpMapInfo[241]={241,453,0x411e388f,2400,1800,598.75,-32770,-598.347107438,37336,202,3,4,61.57,55.01,60.22,58.46,5,1}; -- Eithel Gwaur

	tmpMapInfo[242]={242,454,0x411ee769,1024,768,37.5126390293,2819,-37.3921867073,1278,30,1,2,33.1,-70.2,15.1,-50,3,0}; -- Wells of Langflood
	tmpMapInfo[243]={243,455,0x411ee217,1024,768,119.7139451728,8804,-120.1923076923,-7454,117,1,2,-62.38,-72.7,-67.76,-67.6,5,0}; -- Eastfold Hills Homesteads
	tmpMapInfo[244]={244,456,0x411ee218,1024,768,137.4149659864,10076,-137.3406193078,-7528,115,1,2,-55.25,-71.7,-59.68,-67.43,5,0}; -- Kingstead Meadows Homesteads
	tmpMapInfo[245]={245,457,0x411ee65b,1600,1200,600.9933774834,-30860,-602.6666666667,21045,242,3,2,34.8,51.79,33,53.57,4,1}; -- sundergrot
	tmpMapInfo[246]={246,458,0x411ee4ce,800,600,598.6,-30326,-602.4,20068,242,3,2,32.93,51.02,32.58,51.57,4,1}; -- scrapers claw
	tmpMapInfo[247]={247,459,0x411f1782,800,600,599.1525423729,-30368,-602.7777777778,20840,242,3,2,34.29,50.99,33.85,51.66,4,1}; -- tithroz
	tmpMapInfo[248]={248,460,0x411f1483,800,600,599.2307692308,-30727,-592.1568627451,17653,242,3,2,29.6,51.74,29.05,52.14,4,1}; -- Framsburg
	tmpMapInfo[249]={249,462,0x411f281e,1024,768,95.1300236407,5897,-95.1168224299,2555,153,1,4,24.9,-57.8,19.7,-52.5,4,0}; -- MT Midsummer (wedding)
	tmpMapInfo[250]={250,463,0x411f1bab,1600,1200,1196.5517241379,-62916,-1180,49096,249,3,4,41.25,53.14,40.94,53.44,5,1}; -- Mumak and Keep
	tmpMapInfo[251]={251,464,0x411f1baf,1600,1200,1210.8108108108,-65619,-1188.3333333333,32979,249,3,4,27.55,54.64,26.94,55.05,5,1}; -- The Splintered Shield
	tmpMapInfo[252]={252,465,0x411f1bac,1600,1200,1176.3157894737,-61783,-1200,75841,249,3,4,62.95,52.99,62.45,53.4,5,1}; -- House of Craft
	tmpMapInfo[253]={253,466,0x411f1bad,800,600,1210.7142857143,-64012,-1200,77581,249,3,4,64.56,53.04,64.24,53.35,5,1}; -- The Haven
	tmpMapInfo[254]={254,467,0x411f1ba4,1600,1200,1195.2808988764,-62798,-1195.5696202532,31799,249,3,4,26.55,52.74,25.72,53.66,5,1}; -- Blue Theatre
	tmpMapInfo[255]={255,468,0x411f1ba8,1600,1200,1179.5918367347,-61842,-1202.0833333333,40623,249,3,4,33.54,52.74,33.03,53.25,5,1}; -- Houses of Lore
	tmpMapInfo[256]={256,469,0x411f1ba9,800,600,1207.8947368421,-63680,-1178.947368421,41149,249,3,4,34.77,52.84,34.53,53.27,5,1}; -- High Stables
	tmpMapInfo[257]={257,470,0x411f1ba5,1600,1200,1181.6666666667,-62020,-1201.4705882353,33635,249,3,4,27.84,52.86,27.14,53.46,5,1}; -- The Thirsty Seer
	tmpMapInfo[258]={258,471,0x411f1ba2,1600,1200,1194.8275862069,-61055,-1210.8695652174,66123,249,3,4,54.46,51.44,53.76,52.11,5,1}; -- House of Remedies
	tmpMapInfo[259]={259,472,0x411f1ba3,1600,1200,1206.4634146342,-63455,-1178.275862069,18028,249,3,4,14.95,52.84,53.67,14.63,5,1}; -- Tower of Ecthelion
	tmpMapInfo[260]={260,473,0x411f202b,1600,1200,1218.75,-62248,-1210.2040816327,96160,249,3,4,79.26,51.37,78.75,79.01,5,1}; -- The High Hall
	tmpMapInfo[261]={261,474,0x411f1ba7,1600,1200,1187.5,-62318,-1193.9655172414,38504,249,3,4,32.05,52.94,31.43,53.46,5,1}; -- Southern Great Guesthouse
	tmpMapInfo[262]={262,475,0x411f191e,1600,1200,1203.5714285714,-63230,-1186.1111111111,45716,249,3,4,38.29,53.03,37.87,53.36,5,1}; -- High Guesthouse
	tmpMapInfo[263]={263,476,0x411fb86f,1024,768,51.1730205279,3826,-51.2195121951,2386,30,1,2,46.5,-74.8,31.6,-54.9,3,0}; -- Elderslade
	tmpMapInfo[264]={264,477,0x411fb870,1024,768,51.1730205279,1493,-51.2195121951,-4457,30,1,2,-87.1,-29.2,-102,-9.3,3,0}; -- Elderslade WoTP
	tmpMapInfo[265]={265,478,0x411fa639,1600,1200,601.0416666667,36382,-600,25798,263,3,2,42.8,-59.8,41.3,-58.7,4,1}; -- Wyrmsgraf
	tmpMapInfo[266]={266,479,0x411f2a94,800,600,602.2727272727,-28270,-601.7543859649,41877,263,3,2,69.45,47.36,68.83,47.83,4,1,-64.75,nil,{2,32.7,-61.2}}; -- Annuk-khurfu upper oz>=-64.75
	tmpMapInfo[267]={267,480,0x411f2a95,800,600,602.2727272727,-28270,-607.8947368421,42214,263,3,2,69.16,47.36,68.74,47.83,4,1,nil,-64.76,{2,32.7,-61.2}}; -- Annuk-khurfu lower oz<=-64.76

	tmpMapInfo[268]={268,481,0x411f8704,800,600,606.4516129032,38484,-600,20699,263,3,2,34.2,-62.98,33.91,-62.61,4,1}; -- Shakal-atrad
	tmpMapInfo[269]={269,482,0x411f2a96,800,600,596.2962962963,-27984,-601.5625,42889,263,3,2,70.98,47.4,70.61,47.78,4,1}; -- Tur agal
	tmpMapInfo[270]={270,483,0x411f2a90,800,600,594.4444444444,39659,-611.1111111111,23534,263,3,2,38.16,-66.22,37.89,-65.84,4,1}; -- Drenghol
	tmpMapInfo[271]={271,484,0x411fa635,800,600,796.6666666667,15400,-775,-76293,264,3,2,-98.69,-19.14,-99.05,-18.5,4,1}; -- Ifbar-athrakh
	tmpMapInfo[272]={272,485,0x411f9950,800,600,589.2857142857,11006,-597.3684210526,-60243,264,3,2,-101.14,-18.21,-101.56,-17.78,4,1}; -- Zarkul-sulun
	tmpMapInfo[273]={273,486,0x411f2a91,800,600,613.6363636364,40343,-607.6923076923,22459,263,3,2,36.73,-65.29,36.19,-64.9,4,1}; -- Zudramdan (elderslade)
	tmpMapInfo[274]={274,486,0x411f2a91,800,600,613.6363636364,12361,-607.6923076923,-58729,264,3,2,-96.87,-19.69,-97.41,-19.3,4,1}; -- Zudramdan (WoTP)
	tmpMapInfo[275]={275,483,0x411f2a90,800,600,594.4444444444,12552,-611.1111111112,-58110,264,3,2,-95.44,-20.62,-95.71,-20.24,4,1}; -- Drenghol (WoTP)
	tmpMapInfo[276]={276,487,0x411f2a92,800,600,800,14156,-772,-75358,264,3,2,-97.81,-17.49,-98.18,-16.91,4,1}; -- Howler's notch WoTP -98.12, -16.99
	tmpMapInfo[277]={277,487,0x411f2a92,800,600,800,50637,-772,27781,263,3,2,35.79,-63.1,35.42,-62.51,4,1}; -- Howler's notch elderslades 35.48, -62.59
	tmpMapInfo[278]={278,488,0x411f2a93,1600,1200,603.5714285714,35799,-594.623655914,20280,263,3,2,33.66,-58.36,32.52,-57.55,4,1}; -- Klorgren
	tmpMapInfo[279]={279,481,0x411f8704,800,600,606.4516129032,10829,-600,-59462,264,3,2,-99.4,-17.38,-99.69,-17.01,4,1}; -- Shakal-atrad WoTP
	tmpMapInfo[280]={280,489,0x4120c7c8,1024,768,64.897146649,4417,-65.0575730735,-916,5,1,1,-17.67,-63,-24.9,-54.5,4,0}; -- Wildwood
	tmpMapInfo[281]={281,490,0x41201444,1600,1200,604.0816326531,-31282,-600,-8312,280,3,1,-14.28,52.64,-15.29,53.64,5,1,-65.66,nil,{280,-23.92,-62.09}}; -- Writhenset upper oz min >-65.66
	tmpMapInfo[282]={282,491,0x41201445,1600,1200,602.3255813954,-31275,-600,-8315,280,3,1,-14.2,52.9,-15.5,53.5,5,1,nil,-65.67,{280,-23.92,-62.09}}; -- Writhenset lower oz max <-65.67
	tmpMapInfo[283]={283,494,"GaranStuff/MoorMap/Maps/Agoroth.jpg",1024,768,250.1779359431,17632,-250.3875968992,2086,21,1,1,8.14,-69.91,5.4,-66.83,4,0}; -- Agoroth
	tmpMapInfo[284]={284,495,"GaranStuff/MoorMap/Maps/WoeoftheWillow.jpg",1024,768,250,14608,-250.3546099291,-9345,5,1,1,-37.91,-58.06,-39.88,-54.85,4,0}; -- Woe of the Willow
	tmpMapInfo[285]={285,497,0x41103f10,1600,1200,300,-15115,-299.6153846154,-34764,28,3,1,-116.57,52.31,-119.51,53.77,4,1}; -- Laenan
	tmpMapInfo[286]={286,498,0x41103f0d,1600,1200,300,-14822,-300.6578947368,10827,25,3,1,35.16,51.4,32.87,52.74,4,1}; --Tham Umdur
	tmpMapInfo[287]={287,499,0x411faebb,800,600,788.8888888889,53151,-800,28318,263,3,2,35.29,-67.12,34.78,-66.63,4,1}; --Tithzagaf
-- r14 ?! weird, but we can work with it. TerrainMap will be hosed with this though...
	tmpMapInfo[288]={288,512,0x4120d01b,1024,768,68.7336814621,9869,-68.8137755102,4979,30,3,14,71.8,-140.8,62,-131,3,0}; -- Azanulbizar
	tmpMapInfo[289]={289,513,0x41210192,1024,768,100.0352733686,14379,-99.9305555556,4206,30,3,14,41,-143.2,35.7,-134.1,3,0}; -- Nud-Melek
	tmpMapInfo[290]={290,514,0x4120c123,800,600,596.9230769231,87578,-598.4375,46288,288,3,14,77.26,-146.44,76.44,-145.66,4,1}; -- zagraf muzug
	tmpMapInfo[291]={291,515,0x4121166a,1024,768,28.1429052915,2315,-28.1707827543,1634,30,1,2,57,-79.8,31.3,-53,3,0}; --Mount Gundabad
	tmpMapInfo[292]={292,516,0x4121166f,1024,768,36.887835703,4933,-36.9230769231,-1198,291,1,2,-33.3,-125.8,-52.2,-108.4,4,0}; --Delvings of Gundabad
	tmpMapInfo[293]={293,517,0x41211669,1024,768,85.2686308492,10038,-87.0041039672,-3792,292,1,2,-44.5,-116.8,-50.8,-111.0,5,0}; --Gundabad - Mattugard
	tmpMapInfo[294]={294,518,0x4121166c,1024,768,87.0629370629,10264,-86.9841269841,-3165,292,1,2,-37.2,-117.2,-45,-108.8,5,0}; --Gundabad - Pit of Stonejaws
	tmpMapInfo[295]={295,519,0x4121166d,1024,768,120.4887218045,14789,-119.1335740072,-5573,292,1,2,-47.2,-121.2,-52.3,-115.5,5,0}; --Gundabad - Deepscrave
	tmpMapInfo[296]={296,520,0x4121166b,1024,768,67.3870333988,8838,-67.6923076923,-2183,292,1,2,-33,-125.5,-43.4,-118.6,5,0}; --Gundabad - Clovengap
	tmpMapInfo[297]={297,521,0x41211670,1024,768,87.091222031,11167,-86.9198312236,-3721,292,1,2,-42.9,-124.2,-51.3,-117.3,5,0}; --Gundabad - Gloomingtarn
	tmpMapInfo[298]={298,522,0x41211668,1024,768,53.7848605578,4150,-53.6983669549,3169,291,1,2,56.6,-76,45.5,-59.1,4,0}; --Car Bronach
	tmpMapInfo[299]={299,523,0x4121166e,1024,768,59.8742138365,5098,-60.0706713781,3146,291,1,2,50.7,-78.8,39.9,-70.0,4,0}; --Welkin-lofts
	tmpMapInfo[300]={300,524,0x4120fed1,800,600,305.8823529412,22221,-300,17052,298,3,2,56.04,-71.58,55.62,-71.13,5,1,nil,nil,{2,-56,-71.4}}; -- Eirichav
	tmpMapInfo[301]={301,525,0x411c2de5,1024,768,12,1266,-12,-213,2,1,2,-21,-97,-76,-34,2,0}; -- rohan
	tmpMapInfo[302]={302,526,0x4120c9b5,1600,1200,300,-14199,-300,18958,293,3,2,62.36,49.14,59.86,50.9,6,1}; -- vernozal
	tmpMapInfo[303]={303,527,0x4120d230,800,600,300,-14019,-300,18168,293,3,2,60.01,47.66,59.11,48.45,6,1}; -- Mesem-gairu
	tmpMapInfo[304]={304,528,0x4120dcc7,800,600,295.7142857143,-14388,-298.275862069,16480,293,3,2,54.85,49.63,53.63,50.36,6,1}; -- Agbash-khalt
	tmpMapInfo[305]={305,529,0x4120fe62,800,600,300,22990,-300,15837,298,3,2,52.18,-75.88,51.41,-74.67,6,1}; -- Toll-oivas
	tmpMapInfo[306]={306,530,0x4120fa0f,800,600,300,-14211,-300,17242,293,3,2,57.09,48.05,55.9,49.35,6,1}; -- Shalakam
	tmpMapInfo[307]={307,531,0x4120cb04,800,600,600,-27590,-600,37010,294,3,2,61.53,46.15,60.83,47.14,6,1}; -- Atkat-darag
	tmpMapInfo[308]={308,532,0x412108a6,800,600,0,0,0,0,295,3,2,0,0,0,0,6,1,nil,nil,{2,-48.2,-116.6}}; -- Skrizagraf
	tmpMapInfo[309]={309,533,0x4120d22f,800,600,300,-13651,-300,18194,293,3,2,59.95,46.52,59.33,47.15,6,1}; -- The cradle of pain
	tmpMapInfo[310]={310,534,0x4120fd8d,800,600,300,20303,-300,15539,298,3,2,51.07,-66.73,50.52,-65.97,6,1,nil,nil,{2,-50.9,-65.4}}; -- Skailag
	tmpMapInfo[311]={311,535,0x4120d2c4,800,600,359.477124183,-16639,-354.8387096774,20931,293,3,2,58.54,46.58,57.57,48.24,6,1}; -- kallamdam (360:360 ?)
	tmpMapInfo[312]={312,536,0x4120d231,800,600,294.8717948718,-14345,-301.5625,18317,293,3,2,59.85,49.78,59.1,50.24,6,1}; -- shrine of throkar
	tmpMapInfo[313]={313,537,0x4120cb05,1600,1200,600,-28467,-600,37135,293,3,2,61.43,48.3,60.14,49.29,6,1}; -- caverns of ronglagam
	tmpMapInfo[314]={314,538,0x4120dcc6,800,600,300,-13669,-300,17232,293,3,2,57.1,45.7,55.6,47.8,6,1}; -- Hives of Bruvraum
	tmpMapInfo[315]={315,539,0x4120fa0e,800,600,300,-14008,-300,16696,295,3,2,55.04,47.61,54.24,48.45,6,1,nil,nil,{2,-50.3,-119.4}}; --Vatug-ronk, the Groaning Pit
	tmpMapInfo[316]={316,540,0x4120c694,800,600,600,-29599,-600,37889,294,3,2,62.95,49.87,62.39,50.11,6,1}; --Zul-mazal
	tmpMapInfo[317]={317,541,0x41213775,1600,1200,300,-12787,-300,16667,294,3,2,54.27,44.71,53.08,45.63,6,1}; -- Shakhajat
	tmpMapInfo[318]={318,542,0x4120d270,800,600,300,-14584,-300,17714,293,3,2,58.42,49.47,57.66,50.42,6,1}; -- Stone-giant Dwellings
	tmpMapInfo[319]={319,568,0x412149d2,1600,1200,300,-12539,-300,22005,294,3,2,72.74,44.06,69.84,44.87,6,1}; --Adkhat-zahhar, the Houses of Rest
	tmpMapInfo[320]={320,544,0x41210190,800,600,600,69790,-600,-30629,295,3,2,-51.2,-116.1,-52,-115.3,6,1,nil,nil,{2,-51.1,-115.4}}; -- Durbangh
	tmpMapInfo[321]={321,545,0x41210b69,1600,1200,600,47166,-600,27672,299,3,2,45.69,-78.54,44.49,-75.68,5,1,nil,nil,{2,45.44,76.99}}; -- Thyrstath
	tmpMapInfo[322]={322,546,0x4120d2aa,800,600,300,-14075,-300,17699,293,3,2,58.38,47.82,57.61,48.63,6,1}; -- hadnul-zahar
	tmpMapInfo[323]={323,547,0x41210288,1600,1200,300,-13238,-300,17029,293,3,2,55.13,46.46,54.18,47.12,6,1}; -- Forges of Gundabad
	tmpMapInfo[324]={324,548,0x4120d9d4,800,600,300,-14613,-300,17196,293,3,2,56.61,49.81,56.03,50.42,6,1}; -- cutaig
	tmpMapInfo[325]={325,549,0x411f9e6c,800,600,600,39521,-600,23100,263,3,2,38.4,-65.6,37.5,-64.9,4,1}; -- Tur agal - upper chamber
	tmpMapInfo[326]={326,550,0x412107f6,1600,1200,300,-13716,-300,16641,295,3,2,55.2,46.7,51.5,50.6,4,1}; -- dhurstrok
	tmpMapInfo[327]={327,551,0x41213ed4,2400,1800,500,-20968,-500,35710,297,3,2,70.48,43.28,68.85,45.05,6,1,nil,nil,{2,-49.6,-122.4}}; -- glittengraf
	tmpMapInfo[328]={328,552,0x41213ed3,1600,1200,600,-25941,-600,41309,297,3,2,68.49,44.03,67.41,45.02,6,1,nil,nil,{2,-48.7,-120.2}}; -- ormgren
	tmpMapInfo[329]={329,553,0x41005ccf,1600,1200,1200,-63733,-1200,86552,29,3,1,71.77,53.51,71.48,54.02,5,1}; -- last homely home
	tmpMapInfo[330]={330,554,0x41005cf7,800,600,0,0,0,0,329,3,1,0,0,0,0,6,1}; -- elronds library
	tmpMapInfo[331]={331,555,0x410f2e01,800,600,0,0,0,0,329,3,1,0,0,0,0,6,1}; -- scholar's guild-hall
	tmpMapInfo[332]={332,556,0x411bc621,800,600,0,0,0,0,329,3,1,0,0,0,0,6,1}; -- Tham Send, hall of rest
	tmpMapInfo[333]={333,557,0x41212e5e,800,600,0,0,0,0,329,3,1,0,0,0,0,6,1}; -- Gobeth Teithian, the Archive of Traceries
	tmpMapInfo[334]={334,558,0x410e573c,800,600,0,0,0,0,329,3,1,0,0,0,0,6,1}; -- bilbos room
	tmpMapInfo[335]={335,559,0x41005d7c,800,600,0,0,0,0,329,3,1,0,0,0,0,6,1}; -- Hall of Fire
	tmpMapInfo[336]={336,560,0x412108a5,800,600,600,71200,-600,-28270,295,3,2,-47.54,-118.08,-47.66,-117.97,6,1,nil,nil,{2,-47.5,-117.6}}; -- hideout
	tmpMapInfo[337]={337,561,0x41212bb5,800,600,300,0,-300,0,298,3,2,0,0,0,0,6,1}; -- tur fuar, the drearspire in car bronach
	tmpMapInfo[338]={338,562,0x41211671,1600,1200,400,-17375,-400,21183,296,3,2,51.83,44.17,51.11,46.71,6,1}; -- min navaid
	tmpMapInfo[339]={339,563,0x41210e17,1600,1200,300,-13313,-300,16574,317,3,2,53.47,46.43,52.88,46.66,7,1}; -- shakhajat thorne-room
	tmpMapInfo[340]={340,564,0x4110e1e1,800,600,300,-15106,-300,15839,15,3,2,52.62,50.9,50.85,52.780,5,1}; -- crafting hall
	tmpMapInfo[341]={341,543,0x41210d2f,800,600,600,46643,-600,29505,299,3,2,49.05,-77.49,48.19,-76.71,5,1,nil,nil,{2,48.83,-76.81}}; -- Draurakh
	tmpMapInfo[342]={342,565,0x41210d15,1600,1200,600,44744,-600,26937,299,3,2,44.45,73.45,43.82,73.04,5,1,nil,nil,{2,44.1,-72.8}}; -- bagud-dum
	tmpMapInfo[343]={343,566,0x41210d16,1600,1200,600,44744,-600,26937,342,3,2,43.83,43.58,43.33,72.990,6,1,nil,nil,{2,44.1,-72.8}}; -- secret stair inside bagud-dum
	tmpMapInfo[344]={344,567,0x412108c4,800,600,300,0,-300,0,293,3,2,0,0,0,0,6,1}; -- mattugard troll-den

	PatchDataSave( Turbine.DataScope.Account, "MM_IconInfo", tmpIconInfo);
	PatchDataSave( Turbine.DataScope.Account, "MM_MapInfo", tmpMapInfo);
end
