-- this plugin is used to dynamically update TerrainMap custom annotation .plugindata files
-- this is included in MoorMap to keep custom annotations synchronized between MoorMap and TerrainMap
-- the list of cells is passed via chat commands of the format "0MMCD_action_region_ns_ew_type_nil_name_desc"
-- the data section is encoded as region_h_v_x_y_type_name_desc yes, region is encoded redundantly, once for file name, once for data it's more grief to try to fix this now than to just let it be
-- -- note, to 'update' an annotation you must delete the old and add the new since the encoded string has no other identifier and must match exactly

-- D_region_origNS_origEW_origType_origAllegiance_origName_origDesc
-- S_region_newNS_newEW_newType_newAllegiance_newName_newDesc

-- note, origType and newType can be a type:data for ore nodes, etc

local importPath=string.gsub(getfenv(1)._.Name,"%.MMCust","").."."
import "Turbine";
import "Turbine.UI";
--import "Turbine.UI.Lotro";
import (importPath.."Class");
import (importPath.."VindarPatch");
local debug=Turbine.Shell.IsCommand("MMDebug")
if debug then
	import (importPath.."Table");
end
string.encode=function(str)
	-- replace all non-alpha characters with a % escaped hex code
	local ret=""
	for i,v in ipairs({str:byte(1,-1)}) do
		if (v < 48) or (v>57 and v<65) or (v>90 and v<97) or (v > 125) then
			ret = ret .. "%" .. string.sub("00"..string.format("%x",tonumber(v)),-2)
		else
			ret = ret .. string.char(v)
		end
	end
	return ret
end
string.decode=function(str)
	local ret=""
	while string.len(str)~=0 do
		local char=string.sub(str,1,1)
		if char~="%" then
			ret=ret..char
			str=string.sub(str,2,-1)
		else
			local char=string.char(tonumber("0x"..string.sub(str,2,3)))
			ret=ret..char
			str = string.sub(str,4,-1)
		end
	end
	return ret;
end
string.split=function(str,separator)
	local tmpArray={};
	local tmpElem;
	str=tostring(str);
	if string.find("^$()%.[]*+-?",separator,1,true)~=nil then separator="%"..separator end
	for tmpElem in string.gmatch(str,"[^"..separator.."]*") do
		table.insert(tmpArray,tmpElem);
	end
	local tmpIndex=1;
	while tmpIndex<=#tmpArray do
		if tmpIndex==#tmpArray and tmpArray[tmpIndex]=="" then
			table.remove(tmpArray,tmpIndex);
		else
			if tmpArray[tmpIndex]=="" and tmpArray[tmpIndex+1]~="" then
				table.remove(tmpArray,tmpIndex);
			else
				tmpIndex=tmpIndex+1;
			end
		end
	end
	return tmpArray;
end

-- create a limited version of TerrainMap Grid for offsets
Grid={}
Grid[1]={}
Grid[2]={}
Grid[3]={}
Grid[4]={}
Grid[1].NSOffset=26
Grid[1].EWOffset=-110.75
Grid[2].NSOffset=47.62
Grid[2].EWOffset=-119.6
Grid[3].NSOffset=-15.6
Grid[3].EWOffset=-96.4
Grid[4].NSOffset=-15.6
Grid[4].EWOffset=-25.2

Grid[1].YOffSet=37400
Grid[1].XOffSet=9200
Grid[2].YOffSet=42800
Grid[2].XOffSet=7000
Grid[3].YOffSet=21200
Grid[3].XOffSet=12800
Grid[3].YOffSet=27000
Grid[3].XOffSet=12800
Grid[4].YOffSet=27000
Grid[4].XOffSet=30600

GetHVXYfromNSEW=function(region,ns,ew)
	local ns2=(Grid[region].NSOffset-ns)*1.25
	local ew2=(ew-Grid[region].EWOffset)*1.25
	local h=math.floor(ew2)
	local v=math.floor(ns2)
	local x=math.floor((ew2-h)*200+.5)
	local y=math.floor((ns2-v)*200+.5)
	return {["H"]=h,["V"]=v,["X"]=x,["Y"]=y}
end

local cmdCount=0
local parms;
cellList={}
cmdList={}
local cmds=Turbine.Shell.GetCommands();
if cmds~=nil and type(cmds)=="table" then
	table.sort(cmds,function(arg1,arg2)if arg1<arg2 then return(true) end end);
	for cmdIndex=0,#cmds do
		if cmds[cmdIndex]~=nil then
			if cmdIndex>1 and cmds[cmdIndex]>="1" then
				break
			else
				parms=string.match(cmds[cmdIndex],"0MMCD_(.*)");
				if parms~=nil then
					if debug then Turbine.Shell.WriteLine("cust annot cmd parms:"..tostring(parms)) end
					table.insert(cellList,string.split(parms,"_"))
				end
			end
		end
	end
end

_G.AnnotData={}
local region,row,col
if #cellList==0 then
	-- user loaded automatically, just error out
	if Turbine.Shell.IsCommand("aide") then
		error("N'ex\195\169cutez PAS MMCust. Ce plugin est utilis\195\169 en interne par MoorMap et ne doit pas \195\170tre d\195\169marr\195\169 automatiquement ou par l'utilisateur.",0)
	elseif Turbine.Shell.IsCommand("hilfe") then
		error("F\195\188hren Sie MMCust NICHT aus. Dieses Plugin wird intern von MoorMap verwendet und sollte nicht automatisch oder vom Benutzer gestartet werden.",0)
	else
		error("Do NOT run MMCust. This plugin is used internally by MoorMap and should not be started automatically or by the user.",0)
	end
end
MMList={}
mapInfo=PatchDataLoad( Turbine.DataScope.Account, "MM_MapInfo"); -- also uses .plugindata file to allow custom map support... someday
if mapInfo==nil then mapInfo={} end
for k,v in ipairs(cellList) do
	local index
	local tmpRegion=tonumber(v[2])
	local tmpNS=tonumber(v[3])
	local tmpEW=tonumber(v[4])
	local typeArray=string.split(v[5],"|")
        local tmpType=tonumber(typeArray[1])
        local tmpData=tonumber(typeArray[2])
	local tmpAllegiance=tonumber(v[6])
	local hvxy=GetHVXYfromNSEW(tmpRegion,tmpNS,tmpEW)
-- D_region_origNS_origEW_origType_origAllegiance_origName_origDesc
-- S_region_newNS_newEW_newType_newAllegiance_newName_newDesc

	-- v[1]="S" to save entry or "D" to delete entry

	local tmpAnnotStr=v[2].."_"..tostring(hvxy.H).."_"..tostring(hvxy.V).."_"..tostring(hvxy.X).."_"..tostring(hvxy.Y).."_"..tostring(tmpType).."_"..v[7].."_"..v[8]
	local row2=tostring(math.floor((hvxy.V-1)/4)*4+1)
	local col2=tostring(math.floor((hvxy.H-1)/4)*4+1)
	-- if row2<0 or col2<0 then the annotation is off map (instanced or interior) so do not save to terrainmap
	local row3=tonumber(row2)
	local col3=tonumber(col2)
	if row3~=nil and col3~=nil and row3>=0 and col3>=0 then
		if region==nil or region~=v[2] or row~=row2 or col~=col2 then
			if region~=nil and custAnnot~=nil then
				-- save current annots - files use "TM" prefix since we are saving this data for TerrainMap consumption
				PatchDataSave(Turbine.DataScope.Account, "TM_Cust_Annot_"..region.."_"..row.."_"..col,custAnnot);
			end
			region=v[2]
			row=row2
			col=col2
			-- load existing custom annots if any
			custAnnot=PatchDataLoad(Turbine.DataScope.Account, "TM_Cust_Annot_"..region.."_"..row.."_"..col);
			if custAnnot==nil then custAnnot={} end
		end
		-- scan custAnnot looking for a match to annotstring
		index=nil
		for i,j in ipairs(custAnnot) do
			if j==tmpAnnotStr then
				index=i
				break
			end
		end
		if v[1]=="D" or v[1]=="DT" then
			if index~=nil then
				-- remove the matching entry
				table.remove(custAnnot,index)
			end
		elseif v[1]=="S" or v[1]=="ST" then
			if index==nil then
				-- only save new entry if there isn't an identical match already
				table.insert(custAnnot,tmpAnnotStr)
			end
		end
	end
	-- now save/update/delete to ALL MM maps (MM doesn't save directly to the current map anymore so we need to save to ALL)
	for i,m in ipairs(mapInfo) do
--		if m[11]==1 and m[12]==tmpRegion and m[17]>2 then
		if m[12]==tmpRegion and m[17]>2 then
			if m[13]>=tmpNS and m[14]<=tmpEW and m[15]<=tmpNS and m[16]>=tmpEW then
--				table.insert(MMList,{i,v[1],tmpNS,tmpEW,tmpType,tmpAllegiance,string.decode(v[7])..": "..string.decode(v[8])})
				table.insert(MMList,{i,v[1],tmpNS,tmpEW,tmpType,tmpAllegiance,string.decode(v[7])..": "..string.decode(v[8]),tmpData})
			end
		end
	end
	table.sort(MMList, function(a,b) if a[1]<b[1] then return(true) end end) -- only bother sorting by mapid since that determines file
	local tmpMapID=nil
	local MMAnnots={}

	for k,v in ipairs(MMList) do
		if tmpMapID==nil or tmpMapID~=v[1] then
			if tmpMapID~=nil and MMAnnots~=nil then
				PatchDataSave(Turbine.DataScope.Account, "MM_CustomAnnotations_"..tostring(tmpMapID),MMAnnots)
			end
			MMAnnots=PatchDataLoad(Turbine.DataScope.Account, "MM_CustomAnnotations_"..tostring(v[1]))
			if MMAnnots==nil then MMAnnots={} end
		end
		tmpMapID=v[1]

		local index=nil
		for i,a in ipairs(MMAnnots) do
			-- find entry that matches original value, test ns, ew, type and name

			if a[2]==v[3] and a[3]==v[4] and a[4]==v[5] and a[7]==v[7] and (a[8]==v[8] or v[8]==nil) then
				index=i
				break
			end
		end
		if v[2]=="D" or v[2]=="DM" then
			if index~=nil then
				table.remove(MMAnnots,index)
			end
		elseif v[2]=="S" or v[2]=="SM" then
			if index==nil then
				local tmpVal
				if v[8]==nil then
					tmpVal={v[1],v[3],v[4],v[5],v[6],nil,v[7],0,0,0,0}
				else
					tmpVal={v[1],v[3],v[4],v[5],v[6],nil,v[7],v[8],0,0,0}
				end
				table.insert(MMAnnots,tmpVal)
			else
				MMAnnots[index][5]=v[6] -- update allegiance just in case user changed it
			end
		end
	end
	if tmpMapID~=nil and MMAnnots~=nil then
		PatchDataSave(Turbine.DataScope.Account, "MM_CustomAnnotations_"..tostring(tmpMapID),MMAnnots)
	end
end
if region~=nil and custAnnot~=nil then
	-- save current annots
	PatchDataSave(Turbine.DataScope.Account, "TM_Cust_Annot_"..region.."_"..row.."_"..col,custAnnot);
end
plugin.Unload = function(sender,args)
	-- remove the 'done' command
	Turbine.Shell.RemoveCommand(tmpCmd)
end
tmpCmd=Turbine.ShellCommand()
Turbine.Shell.AddCommand("0MMCC",tmpCmd) -- signal that we are done

