-- this plugin is used to control the export of moormap custom annotations, map by map
-- this is included in MoorMap to keep custom annotations synchronized between MoorMap and TerrainMap
-- this will also ensure that all MoorMap custom annotations are synchronized with all of the maps on which they occur - it was previously possible to edit instances of a custom annotation on each map seperately and led to, um, issues.
-- sample annots (bree)
-- -- 9,-30.4,-52 - test1: test1       reg=1, row=69, col=73,  h=73, v=70, x=87.5, y=100, type=55
-- -- 9,-29.5,-52.7 - Farmer: Farmer   reg=1, row=69, col=69,  h=72, v=69, x=112.5, y=75, type=55
-- -- 9,-29.9,-52.4 - Farmer: Farmer   reg=1, row=69, col=69,  h=72, v=69, x=187.5, y=175, type=55


local importPath=string.gsub(getfenv(1)._.Name,"%.MMExport","").."."
--import (importPath.."Table");
import "Turbine";
import "Turbine.UI";
--import "Turbine.UI.Lotro";
import (importPath.."VindarPatch");

if (tonumber("1,000")==1) then
	function euroNormalize(value)
		return tonumber((string.gsub(value,"%.",",")));
	end
else
	function euroNormalize(value)
		return tonumber((string.gsub(value,",",".")));
	end
end
string.encode=function(str)
	-- replace all non-alpha characters with a % escaped hex code
	local ret=""
	for i,v in ipairs({str:byte(1,-1)}) do
		if (v < 48) or (v>57 and v<65) or (v>90 and v<97) or (v > 125) then
			ret = ret .. "%" .. string.sub("00"..string.format("%x",tonumber(v)),-2)
		else
			ret = ret .. string.char(v)
		end
	end
	return ret
end
string.decode=function(str)
	local ret=""
	while string.len(str)~=0 do
		local char=string.sub(str,1,1)
		if char~="%" then
			ret=ret..char
			str=string.sub(str,2,-1)
		else
			local char=string.char(tonumber("0x"..string.sub(str,2,3)))
			ret=ret..char
			str = string.sub(str,4,-1)
		end
	end
	return ret;
end
string.split=function(str,separator)
	local tmpArray={};
	local tmpElem;
	str=tostring(str);
	if string.find("^$()%.[]*+-?",separator,1,true)~=nil then separator="%"..separator end
	for tmpElem in string.gmatch(str,"[^"..separator.."]*") do
		table.insert(tmpArray,tmpElem);
	end
	local tmpIndex=1;
	while tmpIndex<=#tmpArray do
		if tmpIndex==#tmpArray and tmpArray[tmpIndex]=="" then
			table.remove(tmpArray,tmpIndex);
		else
			if tmpArray[tmpIndex]=="" and tmpArray[tmpIndex+1]~="" then
				table.remove(tmpArray,tmpIndex);
			else
				tmpIndex=tmpIndex+1;
			end
		end
	end
	return tmpArray;
end

local cmdCount=0
local tmpMap
local mapID
local Annots
local cmds=Turbine.Shell.GetCommands();
if cmds~=nil and type(cmds)=="table" then
	table.sort(cmds,function(arg1,arg2)if arg1<arg2 then return(true) end end);
	for cmdIndex=0,#cmds do
		if cmds[cmdIndex]~=nil then
			if cmdIndex>1 and cmds[cmdIndex]>="1" then
				break
			else
				local tmpParm
				tmpParm=string.match(cmds[cmdIndex],"0MMEM_(.*)")
				-- mapID_StartTime
				if tmpParm~=nil then
					tmpParm=string.split(tmpParm,"_")
					mapID=tonumber(tmpParm[1])
					startTime=tonumber(tmpParm[2])
				end
			end
		end
	end
end
-- create a limited version of TerrainMap Grid for offsets
Grid={}
Grid[1]={}
Grid[2]={}
Grid[3]={}
Grid[4]={}
Grid[1].NSOffset=26
Grid[1].EWOffset=-110.75
Grid[2].NSOffset=47.62
Grid[2].EWOffset=-119.6
Grid[3].NSOffset=-15.6
Grid[3].EWOffset=-96.4
Grid[4].NSOffset=-15.6
Grid[4].EWOffset=-25.2

Grid[1].YOffSet=37400
Grid[1].XOffSet=9200
Grid[2].YOffSet=42800
Grid[2].XOffSet=7000
Grid[3].YOffSet=21200
Grid[3].XOffSet=12800
Grid[3].YOffSet=27000
Grid[3].XOffSet=12800
Grid[4].YOffSet=27000
Grid[4].XOffSet=30600

GetHVXYfromNSEW=function(region,ns,ew)
	local ns2=(Grid[region].NSOffset-ns)*1.25
	local ew2=(ew-Grid[region].EWOffset)*1.25
	local h=math.floor(ew2)
	local v=math.floor(ns2)
	local x=math.floor((ew2-h)*200+.5)
	local y=math.floor((ns2-v)*200+.5)
	return {["H"]=h,["V"]=v,["X"]=x,["Y"]=y}
end

if mapID==nil then
	-- user must have loaded plugin automatically...
	if Turbine.Shell.IsCommand("aide") then
		error("N'ex\195\169cutez PAS MMExport. Ce plugin est utilis\195\169 en interne par MoorMap et ne doit pas \195\170tre d\195\169marr\195\169 automatiquement ou par l'utilisateur.",0)
	elseif Turbine.Shell.IsCommand("hilfe") then
		error("F\195\188hren Sie MMExport NICHT aus. Dieses Plugin wird intern von MoorMap verwendet und sollte nicht automatisch oder vom Benutzer gestartet werden.",0)
	else
		error("Do NOT run MMExport. This plugin is used internally by MoorMap and should not be started automatically or by the user.",0)
	end
else
	-- read custom annot file
	Annots=PatchDataLoad( Turbine.DataScope.Account,"MM_CustomAnnotations_"..tostring(mapID))
	if Annots~=nil then
		mapInfo=PatchDataLoad( Turbine.DataScope.Account, "MM_MapInfo")
		if mapInfo~=nil then
			if mapInfo[mapID]~=nil and mapInfo[mapID][11]==1 then
				local hvxy
				local region=mapInfo[mapID][12]
				local name
				local desc
				local pos
				local ns,ew
				local row,col
				local annotList={}
				local MMList={}
				local saveAnnots=false
				for k,v in ipairs(Annots) do
					ns=euroNormalize(v[2])
					ew=euroNormalize(v[3])
					-- determine the h,v,x,y coords from region,ns,ew coords
					hvxy=GetHVXYfromNSEW(region,ns,ew)
					name=v[7]
					pos=string.find(name,":")
					if pos>0 then
						desc=string.sub(name,pos+2)
						name=string.sub(name,1,pos-1)
					else
						desc=name
						name=desc
					end
					if name==nil then name="" end
					if desc==nil then desc="" end
					row=math.floor((hvxy.V-1)/4)*4+1
					col=math.floor((hvxy.H-1)/4)*4+1

					table.insert(annotList,{region,row,col,tostring(region).."_"..tostring(hvxy.H).."_"..tostring(hvxy.V).."_"..tostring(hvxy.X).."_"..tostring(hvxy.Y).."_"..tostring(v[4]).."_"..string.encode(name).."_"..string.encode(desc)})
------------------------------------------------
					if v[12]==nil or v[12]<startTime then
						for i,m in ipairs(mapInfo) do
							if i~=mapID and m[11]==1 and m[12]==region and m[17]>2 then
								if m[13]>=v[2] and m[14]<=v[3] and m[15]<=v[2] and m[16]>=v[3] then
									table.insert(MMList,{i,v[2],v[3],v[4],v[5],v[6],v[7],v[8],v[9],v[10],v[11],Turbine.Engine.GetLocalTime()})
								end
							end
						end
						Annots[k][12]=Turbine.Engine.GetLocalTime()
						saveAnnots=true
					end
------------------------------------------------
				end
				if #annotList>0 then
					-- there is something to save (not just an empty table)
					-- sort the annots by region,row,col so that we don't spend overhead opening and closing files multiple times
					table.sort(annotList,function(a,b) if a[1]<b[1] then return(true) else if a[1]==b[1] and a[2]<b[2] then return (true) else if a[1]==b[1] and a[2]==b[2] and a[3]<b[3] then return (true) end end end end)
					row=nil
					col=nil
					region=nil
					local custAnnot
					local index
					for k,v in ipairs(annotList) do
						if region==nil or region~=v[1] or row~=v[2] or col~=v[3] then
							if region~=nil and custAnnot~=nil then
								PatchDataSave(Turbine.DataScope.Account, "TM_Cust_Annot_"..tostring(region).."_"..tostring(row).."_"..tostring(col),custAnnot)
							end
							region=v[1]
							row=v[2]
							col=v[3]
							custAnnot=PatchDataLoad(Turbine.DataScope.Account, "TM_Cust_Annot_"..tostring(region).."_"..tostring(row).."_"..tostring(col))
							if custAnnot==nil then custAnnot={} end
						end
						index=nil
						for i,j in ipairs(custAnnot) do
							if j==v[4] then
								index=i
								break
							end
						end
						if index==nil then
							-- only save new entry if there isn't an identical match already
							table.insert(custAnnot,v[4])
						end
					end
					if region~=nil and custAnnot~=nil then
						-- save current annots
						PatchDataSave(Turbine.DataScope.Account, "TM_Cust_Annot_"..tostring(region).."_"..tostring(row).."_"..tostring(col),custAnnot);
					end
				end
------------------------------------------------
				table.sort(MMList, function(a,b) if a[1]<b[1] then return(true) end end) -- only bother sorting by mapid since that determines file
				local tmpMapID=nil
				local MMAnnots={}
				for k,v in ipairs(MMList) do
					if tmpMapID==nil or tmpMapID~=v[1] then
						if tmpMapID~=nil and MMAnnots~=nil then
							PatchDataSave(Turbine.DataScope.Account, "MM_CustomAnnotations_"..tostring(tmpMapID),MMAnnots)
						end
						MMAnnots=PatchDataLoad(Turbine.DataScope.Account, "MM_CustomAnnotations_"..tostring(v[1]))
						if MMAnnots==nil then MMAnnots={} end
					end
					tmpMapID=v[1]

					local oldIndex=nil
					for i,a in ipairs(MMAnnots) do
						-- find entry that matches original value, only need to test ns, ew, type and name

						if a[2]==v[2] and a[3]==v[3] and a[4]==v[4] and a[7]==v[7] then
							oldIndex=i
							break
						end
					end

					if oldIndex==nil then
						local tmpVal={} -- create a temporary copy of the entry
						for i=1,#v do -- can't use ipairs since v[6] is null
							tmpVal[i]=v[i]
						end
						table.insert(MMAnnots,tmpVal)
					else
						-- update the allegiance since that is the only thing that might not have matched
						MMAnnots[oldIndex][5]=v[5]
					end
				end
				if tmpMapID~=nil and MMAnnots~=nil then
					PatchDataSave(Turbine.DataScope.Account, "MM_CustomAnnotations_"..tostring(tmpMapID),MMAnnots)
				end
------------------------------------------------
				if saveAnnots then
					PatchDataSave( Turbine.DataScope.Account,"MM_CustomAnnotations_"..tostring(mapID),Annots)
				end
			end
		end
	end
end

plugin.Unload = function(sender,args)
	-- remove our commands
	Turbine.Shell.RemoveCommand(doneCmd)
end
doneCmd=Turbine.ShellCommand()
Turbine.Shell.AddCommand("0MMEC",doneCmd) -- signal that we are done
