-- This plugin gets it's parameters from the "0MMP_Type_mapID_curMapID_searchText" command (registered by MoorMap before this plugin is loaded)
-- this plugin then processes each map's data file, searching for the parameter and creating a "0MMR_" result command for each match
-- once done, it creates the "0MMC" command which causes MoorMap to process the "0MMR_" commands and then unload this plugin
-- in this plugin's unload, the "0MMR_" commands and "0MMC" are removed since MoorMap processes them before unloading this plugin
-- Note, this plugins MUST be unloaded and reloaded between searches so that the data files are reprocessed each time (reimporting an already
-- -- loaded file will not reexecute the code in the file. By unloading the plugin we reexecute each import file and can thus reuse the same
-- -- variables allowing the values to be flushed from memory after being searched. This SIGNIFICANTLY reduces the memory footprint of the
-- -- plugin.

local importPath=string.gsub(getfenv(1)._.Name,"%.MMSearch","").."."
local resourcePath=string.gsub(importPath,"%.","/").."Resources/"

import (importPath.."Class");
import (importPath.."Table");
import (importPath.."VindarPatch");

import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";

_G.tmpAnnotations={}
_G.tmpMapString={}

respCmd={}
replaceStr={[128]="A",[129]="A",[130]="A",[131]="A",[132]="A",[133]="A",[134]="AE",[135]="C",[136]="E",[137]="E",[138]="E",[139]="E",[140]="I",[141]="I",[142]="I",[143]="I",[144]="",[145]="N",[146]="O",[147]="O",[148]="O",[149]="O",[150]="O",[151]="",[152]="O",[153]="U",[154]="U",[155]="U",[156]="U",[157]="Y",[158]="Y",[159]="sz",[160]="a",[161]="a",[162]="a",[163]="a",[164]="a",[165]="a",[166]="ae",[167]="c",[168]="e",[169]="e",[170]="e",[171]="e",[172]="i",[173]="i",[174]="i",[175]="i",[176]="o",[177]="n",[178]="o",[179]="o",[180]="o",[181]="o",[182]="o",[183]="",[184]="o",[185]="u",[186]="u",[187]="u",[188]="u",[189]="y",[190]="y",[191]="y"}
string.stripaccent=function(str)
	local ret = "";
	if str~=nil then
		ret=""
		local replace=false
		for i,v in ipairs({str:byte(1,-1)}) do
			if replace then
				replace=false
				if replaceStr[v]~=nil then
					ret=ret..replaceStr[v]
				end
			else
				if (v==195) then
					replace=true
				else
					ret = ret .. string.char(v);
				end
			end
		end
	end
	return ret;
end
string.split=function(str,separator)
	local tmpArray={};
	local tmpElem;
	str=tostring(str);
	if string.find("^$()%.[]*+-?",separator,1,true)~=nil then separator="%"..separator end
	for tmpElem in string.gmatch(str,"[^"..separator.."]*") do
		table.insert(tmpArray,tmpElem);
	end
	local tmpIndex=1;
	while tmpIndex<=#tmpArray do
		if tmpIndex==#tmpArray and tmpArray[tmpIndex]=="" then
			table.remove(tmpArray,tmpIndex);
		else
			if tmpArray[tmpIndex]=="" and tmpArray[tmpIndex+1]~="" then
				table.remove(tmpArray,tmpIndex);
			else
				tmpIndex=tmpIndex+1;
			end
		end
	end
	return tmpArray;
end
string.encode=function(str)
	-- replace all non-alpha characters with a % escaped hex code
	local ret=""
	for i,v in ipairs({str:byte(1,-1)}) do
		if (v < 48) or (v>57 and v<65) or (v>90 and v<97) or (v > 125) then
			ret = ret .. "%" .. string.sub("00"..string.format("%x",tonumber(v)),-2)
		else
			ret = ret .. string.char(v)
		end
	end
	return ret
end
string.decode=function(str)
	local ret=""
	while string.len(str)~=0 do
		local char=string.sub(str,1,1)
		if char~="%" then
			ret=ret..char
			str=string.sub(str,2,-1)
		else
			local char=string.char(tonumber("0x"..string.sub(str,2,3)))
			ret=ret..char
			str = string.sub(str,4,-1)
		end
	end
	return ret;
end

local parms
local cmds=Turbine.Shell.GetCommands();
if cmds~=nil and type(cmds)=="table" then
	table.sort(cmds,function(arg1,arg2)if arg1<arg2 then return(true) end end);
	for cmdIndex=0,#cmds do
		if cmds[cmdIndex]~=nil then
			if cmdIndex>1 and cmds[cmdIndex]>="1" then
				break
			else
				parms=string.match(cmds[cmdIndex],"0MMP_(.*)");
				if parms~=nil then
					parms=string.split(parms,"_")
					parms[4]=string.decode(parms[4])
					parms[5]=string.decode(parms[5])
					break
				end
			end
		end
	end
end
if parms==nil then
	if Turbine.Shell.IsCommand("aide") then
		error("N'ex\195\169cutez PAS MMSearch. Ce plugin est utilis\195\169 en interne par MoorMap et ne doit pas \195\170tre d\195\169marr\195\169 automatiquement ou par l'utilisateur.",0)
	elseif Turbine.Shell.IsCommand("hilfe") then
		error("F\195\188hren Sie MMSearch NICHT aus. Dieses Plugin wird intern von MoorMap verwendet und sollte nicht automatisch oder vom Benutzer gestartet werden.",0)
	else
		error("Do NOT run MMSearch. This plugin is used internally by MoorMap and should not be started automatically or by the user.",0)
	end
end
worldName=parms[4]
searchName=parms[5]
searchType=tonumber(parms[1])
mapID=tonumber(parms[2])
curMapID=tonumber(parms[3])

--Turbine.Shell.WriteLine("MM_Search:"..tostring(searchType)..","..tostring(mapID)..","..tostring(curMapID)..","..tostring(searchName))
-- for now, just generate the completed message and unload handler
plugin.Unload = function(statusDisplay,sender,args)
	-- remove the "0MMR_" commands and the "0MMC" command
	for k,v in pairs(respCmd) do
		Turbine.Shell.RemoveCommand(v)
	end
	-- clean up last set of annotations
	_G.tmpAnnotations=nil
	_G.tmpMapString=nil
end
local result,error;
local success,retval;

if searchType==1 or searchType==3 then
-- search .lua files
	_G.tmpAnnotations={}
	_G.tmpMapString={}
	result,error=loadstring("import \"GaranStuff.MoorMap.Data.MapData_"..mapID.."\"");
	if result==nil then
		Turbine.Shell.WriteLine("Error:"..tostring(error));
	else
		-- we may not have a data file for all maps (some have no annotations)
		success,retval=pcall(result);
		if success then
			for k,v in ipairs(_G.tmpAnnotations) do
				if string.find(string.lower(string.stripaccent(_G.tmpMapString[1][v[6]])),searchName)~=nil then
					local tmpStr=string.split(tmpMapString[1][v[6]],":")
					local newCmd=Turbine.ShellCommand();
					table.insert(respCmd,newCmd)
					if tmpStr[1]~=nil then
						tmpStr[1]=string.encode(tmpStr[1])
					end
					if tmpStr[2]~=nil then
						tmpStr[2]=string.encode(tmpStr[2])
					end
					Turbine.Shell.AddCommand("0MMR_"..tostring(mapID).."_"..tostring(v[2]).."_"..tostring(v[3]).."_"..tostring(tmpStr[1]).."_"..tostring(tmpStr[2]),newCmd);
				end
			end
		else
--			Turbine.Shell.WriteLine("Error:"..tostring(retval))
		end
	end

	if mapID==1 then
		-- search the server specific lua file.
		_G.tmpAnnotations={}
		_G.tmpMapString={}
		result,error=loadstring("import \"GaranStuff.MoorMap.Data.MapData_"..mapID.."_"..worldName.."\"");
		if result==nil then
			Turbine.Shell.WriteLine("Error:"..tostring(error));
		else
			-- we may not have a data file for all maps (some have no annotations)
			success,retval=pcall(result);
			if success then
				for k,v in ipairs(_G.tmpAnnotations) do
					if string.find(string.lower(string.stripaccent(_G.tmpMapString[1][v[6]])),searchName)~=nil then
						local tmpStr=string.split(tmpMapString[1][v[6]],":")
						local newCmd=Turbine.ShellCommand();
						table.insert(respCmd,newCmd)
						if tmpStr[1]~=nil then
							tmpStr[1]=string.encode(tmpStr[1])
						end
						if tmpStr[2]~=nil then
							tmpStr[2]=string.encode(tmpStr[2])
						end
						Turbine.Shell.AddCommand("0MMR_"..tostring(mapID).."_"..tostring(v[2]).."_"..tostring(v[3]).."_"..tostring(tmpStr[1]).."_"..tostring(tmpStr[2]),newCmd);
					end
				end
			else
	--			Turbine.Shell.WriteLine("Error:"..tostring(retval))
			end
		end
	end
end
if (searchType==2 or searchType==3) and mapID~=curMapID then
-- search .plugindata file
	_G.tmpAnnotations=PatchDataLoad( Turbine.DataScope.Account, "MM_CustomAnnotations_"..mapID);
	if _G.tmpAnnotations~=nil then
		for k,v in ipairs(_G.tmpAnnotations) do
			if string.find(string.lower(string.stripaccent(v[7])),searchName)~=nil then
				local tmpStr=string.split(v[7],":")
				local newCmd=Turbine.ShellCommand();
				table.insert(respCmd,newCmd)
				if tmpStr[1]~=nil then
					tmpStr[1]=string.encode(tmpStr[1])
				end
				if tmpStr[2]~=nil then
					tmpStr[2]=string.encode(tmpStr[2])
				end
				Turbine.Shell.AddCommand("0MMR_"..tostring(mapID).."_"..tostring(v[2]).."_"..tostring(v[3]).."_"..tostring(tmpStr[1]).."_"..tostring(tmpStr[2]),newCmd);
			end
		end
	else
--			Turbine.Shell.WriteLine("Error:"..tostring(retval))
	end
end
local unloadCmd=Turbine.ShellCommand()
table.insert(respCmd,unloadCmd);
Turbine.Shell.AddCommand("0MMC",unloadCmd);
