MinimizedWindow = class(Turbine.UI.Window);
function MinimizedWindow:Constructor()
	Turbine.UI.Window.Constructor( self );
	self:SetVisible(false);
-- replace with an appropriate image
	self:SetSize(32,32);
	self.UpImage="GaranStuff/MoorMap/Resources/map_up.jpg"
	self.DragImage="GaranStuff/MoorMap/Resources/map_up.jpg"
	self.HoverImage="GaranStuff/MoorMap/Resources/map_up.jpg"
	self.UseMiniIcon=false;
	self.DefaultOpacity=.3;
	self.MiniIconOpaque=true;

	local left=1;
	local top=Turbine.UI.Display.GetHeight()-self:GetHeight()-1;
	local tmpSettings={};	

	tmpSettings=PatchDataLoad(Turbine.DataScope.Character, "MoorMapSettings");
	if tmpSettings==nil then
		tmpSettings=PatchDataLoad(Turbine.DataScope.Account, "MoorMapSettings");
		if tmpSettings==nil then tmpSettings={} end
	end
	if tostring(type(tmpSettings))=="table" then
		if tmpSettings[1]~=nil then
			-- convert old format to new format
			for index,data in ipairs(tmpSettings) do
				tmpSettings[data[1]]=Table.Copy(data[2]);
				tmpSettings[index]=nil;
			end
		end
		top=euroNormalize(tmpSettings.IconTopPercent)
		if top==nil then
			top=euroNormalize(tmpSettings.IconTop)
		else
			top=top*Turbine.UI.Display.GetHeight();
		end
		if top==nil then top=0 end
		left=euroNormalize(tmpSettings.IconLeftPercent)
		if left==nil then
			left=euroNormalize(tmpSettings.IconLeft)
		else
			left=left*Turbine.UI.Display.GetWidth();
		end
		if left==nil then left=0 end
		if tmpSettings.UseMiniIcon~=nil and tmpSettings.UseMiniIcon==true then
			self.UseMiniIcon=true;
			self.UpImage="GaranStuff/MoorMap/Resources/mini_icon.tga";
			self.DragImage="GaranStuff/MoorMap/Resources/mini_icon.tga";
			self.HoverImage="GaranStuff/MoorMap/Resources/mini_hover.tga";

		end
		if tmpSettings.MiniIconOpaque~=nil and tmpSettings.MiniIconOpaque==false then
			self.MiniIconOpaque=false;
		end
		-- account for changed resolution
		if left<0 then left=0 end;
		if left>(Turbine.UI.Display.GetWidth()-self:GetWidth()) then left=Turbine.UI.Display.GetWidth()-self:GetWidth() end;
		if top<0 then top=0 end;
		if top>(Turbine.UI.Display.GetHeight()-self:GetHeight()) then top=Turbine.UI.Display.GetHeight()-self:GetHeight() end;
	end
	self:SetBackground(self.UpImage);
	if self.UseMiniIcon then
		self:SetSize(16,16);
	end
	if self.UseMiniIcon and self.MiniIconOpaque then
		self.DefaultOpacity=1;
	else
		self.DefaultOpacity=.3;
	end
	self:SetOpacity(self.DefaultOpacity);
	self:SetPosition( left, top );
	self:SetZOrder(self:GetZOrder()+1);

	self.MouseClick = function(sender,args)
		self:SetBackground(self.UpImage);
		if self.Moving then
			self.Moving=false;
			self.MoveX=-1;
		else
			self:SetVisible(false);
			mapWindow:SetVisible(true);
		end
	end

	self.MoveX=-1;
	self.MoveY=0;
	self.Moving=false;

	self.MouseDown=function(sender,args)
		if self:IsControlKeyDown() or self:IsShiftKeyDown() or self:IsAltKeyDown() then
			self:SetBackground(self.HoverImage);
			self.MoveX=args.X;
			self.MoveY=args.Y;
		end
	end
	self.MouseUp=function(sender,args)
		self:SetBackground(self.UpImage);
		self.MoveX=-1;
		self.MoveY=0;
	end

	self.MouseEnter=function(sender,args)
		self:SetOpacity(1);
	end

	self.MouseLeave=function(sender,args)
		self:SetOpacity(self.DefaultOpacity);
	end

	self.MouseMove=function(sender,args)
		if self.MoveX~=-1 and (args.X~=self.MoveX or args.Y~= self.MoveY) then
			self:SetBackground(self.DragImage);
			self.Moving=true;
			local newLeft=self:GetLeft()-(self.MoveX-args.X)
			local newTop=self:GetTop()-(self.MoveY-args.Y)
			if newLeft<0 then newLeft=0 end;
			if newLeft>(Turbine.UI.Display.GetWidth()-self:GetWidth()) then newLeft=Turbine.UI.Display.GetWidth()-self:GetWidth() end;
			if newTop<0 then newTop=0 end;
			if newTop>(Turbine.UI.Display.GetHeight()-self:GetHeight()) then newTop=Turbine.UI.Display.GetHeight()-self:GetHeight() end;
			self:SetPosition(newLeft,newTop);
			optionsCanvas.IconLeftValue:SetText(tostring(minWindow:GetLeft()))
			optionsCanvas.IconTopValue:SetText(tostring(minWindow:GetTop()))
		end
	end

	self.Update=function(sender,args)
		self.SetWantsUpdates(false); -- turn updates off... no need to waste machine cycles on this
	end
	self.GetUseMiniIcon=function()
		return self.UseMiniIcon;
	end
	self.SetUseMiniIcon=function(sender,value)
		self.UseMiniIcon=value;
		if value==true then
			self.UpImage="GaranStuff/MoorMap/Resources/mini_icon.tga";
			self.DragImage="GaranStuff/MoorMap/Resources/mini_icon.tga";
			self.HoverImage="GaranStuff/MoorMap/Resources/mini_hover.tga";
		else
			self.UpImage="GaranStuff/MoorMap/Resources/map_up.jpg"
			self.DragImage="GaranStuff/MoorMap/Resources/map_up.jpg"
			self.HoverImage="GaranStuff/MoorMap/Resources/map_up.jpg"
		end
		if self.UseMiniIcon and self.MiniIconOpaque then
			self.DefaultOpacity=1;
		else
			self.DefaultOpacity=.3;
		end
		self:SetOpacity(self.DefaultOpacity);
		self:SetBackground(self.UpImage);
		if self.UseMiniIcon then
			self:SetSize(16,16);
		else
			self:SetSize(32,32);
		end
	end
	self.GetMiniIconOpaque=function()
		return self.MiniIconOpaque;
	end
	self.SetMiniIconOpaque=function(sender,value)
		self.MiniIconOpaque=value;
		if self.UseMiniIcon and self.MiniIconOpaque then
			self.DefaultOpacity=1;
		else
			self.DefaultOpacity=.3;
		end
		self:SetOpacity(self.DefaultOpacity);
	end
end       
minWindow=MinimizedWindow()